@@ -1,11 +1,11 @@
+from pcs.cli.file import metadata
+from pcs.cli.reports import output
+from pcs.common import file as pcs_file
 from pcs.common import (
-    file as pcs_file,
     file_type_codes,
     reports,
 )
 from pcs.common.reports.item import ReportItem
-from pcs.cli.reports import output
-from pcs.cli.file import metadata
 from pcs.lib.errors import LibraryError
 
 
@@ -46,7 +46,7 @@ def middleware_config(config_path, key_path):
                         file_path=e.metadata.path,
                     )
                 )
-            )
+            ) from e
         return {
             "config_data": config_data,
             "key_data": key_data,
@@ -80,7 +80,7 @@ def middleware_config(config_path, key_path):
                         file_path=e.metadata.path,
                     )
                 )
-            )
+            ) from e
 
     def apply(next_in_line, env, *args, **kwargs):
         env.booth = create_booth_env() if is_mocked_environment else {}
