@@ -1,8 +1,5 @@
-from .types import (
-    ForceCode as F,
-    MessageCode as M,
-)
-
+from .types import ForceCode as F
+from .types import MessageCode as M
 
 # force categories
 FORCE = F("FORCE")
@@ -35,6 +32,10 @@ ADD_REMOVE_CANNOT_PUT_ITEM_NEXT_TO_ITSELF = M(
 ADD_REMOVE_CANNOT_SPECIFY_ADJACENT_ITEM_WITHOUT_ITEMS_TO_ADD = M(
     "ADD_REMOVE_CANNOT_SPECIFY_ADJACENT_ITEM_WITHOUT_ITEMS_TO_ADD"
 )
+AGENT_GENERIC_ERROR = M("AGENT_GENERIC_ERROR")
+AGENT_IMPLEMENTS_UNSUPPORTED_OCF_VERSION = M(
+    "AGENT_IMPLEMENTS_UNSUPPORTED_OCF_VERSION"
+)
 AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE = M("AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE")
 AGENT_NAME_GUESS_FOUND_NONE = M("AGENT_NAME_GUESS_FOUND_NONE")
 AGENT_NAME_GUESSED = M("AGENT_NAME_GUESSED")
@@ -54,6 +55,7 @@ BOOTH_INVALID_NAME = M("BOOTH_INVALID_NAME")
 BOOTH_LACK_OF_SITES = M("BOOTH_LACK_OF_SITES")
 BOOTH_MULTIPLE_TIMES_IN_CIB = M("BOOTH_MULTIPLE_TIMES_IN_CIB")
 BOOTH_NOT_EXISTS_IN_CIB = M("BOOTH_NOT_EXISTS_IN_CIB")
+BOOTH_PATH_NOT_EXISTS = M("BOOTH_PATH_NOT_EXISTS")
 BOOTH_PEERS_STATUS_ERROR = M("BOOTH_PEERS_STATUS_ERROR")
 BOOTH_TICKET_DOES_NOT_EXIST = M("BOOTH_TICKET_DOES_NOT_EXIST")
 BOOTH_TICKET_DUPLICATE = M("BOOTH_TICKET_DUPLICATE")
@@ -95,10 +97,14 @@ CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE = M(
 CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER = M(
     "CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER"
 )
+CANNOT_MOVE_RESOURCE_NOT_RUNNING = M("CANNOT_MOVE_RESOURCE_NOT_RUNNING")
 CANNOT_MOVE_RESOURCE_STOPPED_NO_NODE_SPECIFIED = M(
     "CANNOT_MOVE_RESOURCE_STOPPED_NO_NODE_SPECIFIED"
 )
 CANNOT_REMOVE_ALL_CLUSTER_NODES = M("CANNOT_REMOVE_ALL_CLUSTER_NODES")
+CANNOT_SET_ORDER_CONSTRAINTS_FOR_RESOURCES_IN_THE_SAME_GROUP = M(
+    "CANNOT_SET_ORDER_CONSTRAINTS_FOR_RESOURCES_IN_THE_SAME_GROUP"
+)
 CANNOT_UNMOVE_UNBAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE = M(
     "CANNOT_UNMOVE_UNBAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE"
 )
@@ -140,12 +146,14 @@ CLUSTER_RESTART_REQUIRED_TO_APPLY_CHANGES = M(
 CLUSTER_SETUP_SUCCESS = M("CLUSTER_SETUP_SUCCESS")
 CLUSTER_START_STARTED = M("CLUSTER_START_STARTED")
 CLUSTER_START_SUCCESS = M("CLUSTER_START_SUCCESS")
+CLUSTER_UUID_ALREADY_SET = M("CLUSTER_UUID_ALREADY_SET")
 CLUSTER_WILL_BE_DESTROYED = M("CLUSTER_WILL_BE_DESTROYED")
 LIVE_ENVIRONMENT_NOT_CONSISTENT = M("LIVE_ENVIRONMENT_NOT_CONSISTENT")
 LIVE_ENVIRONMENT_REQUIRED = M("LIVE_ENVIRONMENT_REQUIRED")
 LIVE_ENVIRONMENT_REQUIRED_FOR_LOCAL_NODE = M(
     "LIVE_ENVIRONMENT_REQUIRED_FOR_LOCAL_NODE"
 )
+RESOURCE_STONITH_COMMANDS_MISMATCH = M("RESOURCE_STONITH_COMMANDS_MISMATCH")
 COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK = M(
     "COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK"
 )
@@ -226,8 +234,11 @@ COROSYNC_TRANSPORT_UNSUPPORTED_OPTIONS = M(
     "COROSYNC_TRANSPORT_UNSUPPORTED_OPTIONS"
 )
 CRM_MON_ERROR = M("CRM_MON_ERROR")
+# TODO remove
 DEFAULTS_CAN_BE_OVERRIDEN = M("DEFAULTS_CAN_BE_OVERRIDEN")
+DEFAULTS_CAN_BE_OVERRIDDEN = M("DEFAULTS_CAN_BE_OVERRIDDEN")
 DEPRECATED_OPTION = M("DEPRECATED_OPTION")
+DEPRECATED_OPTION_VALUE = M("DEPRECATED_OPTION_VALUE")
 DR_CONFIG_ALREADY_EXIST = M("DR_CONFIG_ALREADY_EXIST")
 DR_CONFIG_DOES_NOT_EXIST = M("DR_CONFIG_DOES_NOT_EXIST")
 DUPLICATE_CONSTRAINTS_EXIST = M("DUPLICATE_CONSTRAINTS_EXIST")
@@ -267,6 +278,7 @@ INVALID_TIMEOUT_VALUE = M("INVALID_TIMEOUT_VALUE")
 MULTIPLE_SCORE_OPTIONS = M("MULTIPLE_SCORE_OPTIONS")
 MULTIPLE_RESULTS_FOUND = M("MULTIPLE_RESULTS_FOUND")
 MUTUALLY_EXCLUSIVE_OPTIONS = M("MUTUALLY_EXCLUSIVE_OPTIONS")
+NO_ACTION_NECESSARY = M("NO_ACTION_NECESSARY")
 NODE_ADDRESSES_ALREADY_EXIST = M("NODE_ADDRESSES_ALREADY_EXIST")
 NODE_ADDRESSES_CANNOT_BE_EMPTY = M("NODE_ADDRESSES_CANNOT_BE_EMPTY")
 NODE_ADDRESSES_DUPLICATION = M("NODE_ADDRESSES_DUPLICATION")
@@ -364,6 +376,9 @@ QDEVICE_REMOVE_OR_CLUSTER_STOP_NEEDED = M(
     "QDEVICE_REMOVE_OR_CLUSTER_STOP_NEEDED"
 )
 QDEVICE_USED_BY_CLUSTERS = M("QDEVICE_USED_BY_CLUSTERS")
+CLONING_STONITH_RESOURCES_HAS_NO_EFFECT = M(
+    "CLONING_STONITH_RESOURCES_HAS_NO_EFFECT"
+)
 REQUIRED_OPTIONS_ARE_MISSING = M("REQUIRED_OPTIONS_ARE_MISSING")
 REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING = M(
     "REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING"
@@ -388,6 +403,9 @@ RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE = M("RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE")
 RESOURCE_INSTANCE_ATTR_VALUE_NOT_UNIQUE = M(
     "RESOURCE_INSTANCE_ATTR_VALUE_NOT_UNIQUE"
 )
+RESOURCE_INSTANCE_ATTR_GROUP_VALUE_NOT_UNIQUE = M(
+    "RESOURCE_INSTANCE_ATTR_GROUP_VALUE_NOT_UNIQUE"
+)
 RESOURCE_IS_GUEST_NODE_ALREADY = M("RESOURCE_IS_GUEST_NODE_ALREADY")
 RESOURCE_IS_UNMANAGED = M("RESOURCE_IS_UNMANAGED")
 RESOURCE_MANAGED_NO_MONITOR_ENABLED = M("RESOURCE_MANAGED_NO_MONITOR_ENABLED")
@@ -405,8 +423,10 @@ RESOURCE_UNMOVE_UNBAN_PCMK_SUCCESS = M("RESOURCE_UNMOVE_UNBAN_PCMK_SUCCESS")
 RESOURCE_UNMOVE_UNBAN_PCMK_EXPIRED_NOT_SUPPORTED = M(
     "RESOURCE_UNMOVE_UNBAN_PCMK_EXPIRED_NOT_SUPPORTED"
 )
+RESOURCE_MAY_OR_MAY_NOT_MOVE = M("RESOURCE_MAY_OR_MAY_NOT_MOVE")
 RESOURCE_MOVE_CONSTRAINT_CREATED = M("RESOURCE_MOVE_CONSTRAINT_CREATED")
 RESOURCE_MOVE_CONSTRAINT_REMOVED = M("RESOURCE_MOVE_CONSTRAINT_REMOVED")
+RESOURCE_MOVE_NOT_AFFECTING_RESOURCE = M("RESOURCE_MOVE_NOT_AFFECTING_RESOURCE")
 RESOURCE_MOVE_AFFECTS_OTRHER_RESOURCES = M(
     "RESOURCE_MOVE_AFFECTS_OTRHER_RESOURCES"
 )
@@ -460,7 +480,17 @@ SERVICE_VERSION_MISMATCH = M("SERVICE_VERSION_MISMATCH")
 UNABLE_TO_GET_RESOURCE_OPERATION_DIGESTS = M(
     "UNABLE_TO_GET_RESOURCE_OPERATION_DIGESTS"
 )
+STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_SET = M(
+    "STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_SET"
+)
+STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_UNSET = M(
+    "STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_UNSET"
+)
+STONITH_WATCHDOG_TIMEOUT_TOO_SMALL = M("STONITH_WATCHDOG_TIMEOUT_TOO_SMALL")
 STONITH_RESOURCES_DO_NOT_EXIST = M("STONITH_RESOURCES_DO_NOT_EXIST")
+STONITH_RESTARTLESS_UPDATE_MISSING_MPATH_KEYS = M(
+    "STONITH_RESTARTLESS_UPDATE_MISSING_MPATH_KEYS"
+)
 STONITH_RESTARTLESS_UPDATE_OF_SCSI_DEVICES_NOT_SUPPORTED = M(
     "STONITH_RESTARTLESS_UPDATE_OF_SCSI_DEVICES_NOT_SUPPORTED"
 )
