@@ -11,8 +11,10 @@ from typing import (
     Union,
 )
 
+ListOfStrings = List[str]  # Intetionaly not Sequence so string is prohibited
 
-def indent(line_list: Iterable[str], indent_step: int = 2) -> List[str]:
+
+def indent(line_list: ListOfStrings, indent_step: int = 2) -> List[str]:
     """
     return line list where each line of input is prefixed by N spaces
 
@@ -25,35 +27,66 @@ def indent(line_list: Iterable[str], indent_step: int = 2) -> List[str]:
     ]
 
 
-def format_list(
-    item_list: List[str],  # Intetionaly not Sequence so string is prohibited
+def outdent(line_list: ListOfStrings) -> List[str]:
+    if not line_list:
+        return []
+    smallest_indentation = min(
+        [len(line) - len(line.lstrip(" ")) for line in line_list if line]
+    )
+    return [line[smallest_indentation:] for line in line_list]
+
+
+def format_list_base(
+    item_list: ListOfStrings,
     separator: str = ", ",
 ) -> str:
-    item_list = sorted(item_list)
+    return separator.join(item_list)
 
-    to_value = lambda item: f"'{item}'"
 
-    if len(item_list) == 1:
-        return to_value(item_list[0])
+def format_list_dont_sort(
+    item_list: ListOfStrings,
+    separator: str = ", ",
+) -> str:
+    return format_list_base(quote_items(item_list), separator)
 
-    return separator.join(sorted([to_value(item) for item in item_list]))
+
+def format_list(
+    item_list: ListOfStrings,
+    separator: str = ", ",
+) -> str:
+    return format_list_dont_sort(sorted(item_list), separator)
 
 
 def format_list_custom_last_separator(
-    item_list: List[str],  # Intetionaly not Sequence so string is prohibited
+    item_list: ListOfStrings,
     last_separator: str,
     separator: str = ", ",
 ) -> str:
-    item_list = sorted(item_list)
-    if len(item_list) < 2:
-        return format_list(item_list, separator=separator)
-    return "{}{}{}".format(
-        format_list(item_list[:-1], separator=separator),
-        last_separator,
-        format_list(item_list[-1:], separator=separator),
+    return format_list_custom_last_separator_dont_sort(
+        quote_items(sorted(item_list)), last_separator, separator
     )
 
 
+def format_list_custom_last_separator_dont_sort(
+    item_list: ListOfStrings,
+    last_separator: str,
+    separator: str = ", ",
+) -> str:
+    if len(item_list) < 2:
+        return format_list_base(item_list)
+    return format_list_base(
+        [
+            format_list_base(item_list[:-1], separator=separator),
+            format_list_base(item_list[-1:]),
+        ],
+        separator=last_separator,
+    )
+
+
+def quote_items(item_list: ListOfStrings) -> List[str]:
+    return [f"'{item}'" for item in item_list]
+
+
 # For now, Tuple[str, str] is sufficient. Feel free to change it if needed,
 # e.g. when values can be integers.
 def format_name_value_list(item_list: Sequence[Tuple[str, str]]) -> List[str]:
@@ -88,6 +121,12 @@ def join_multilines(strings: Iterable[str]) -> str:
     return "\n".join([a.strip() for a in strings if a.strip()])
 
 
+def split_multiline(string: str) -> List[str]:
+    return [
+        line for line in [line.strip() for line in string.splitlines()] if line
+    ]
+
+
 def format_optional(
     value: Any,
     template: str = "{} ",
