@@ -1,5 +1,8 @@
+from pcs.daemon.auth import (
+    authorize_user,
+    check_user_groups,
+)
 from pcs.daemon.session import Storage
-from pcs.daemon.auth import check_user_groups, authorize_user
 
 PCSD_SESSION = "pcsd.sid"
 
@@ -13,6 +16,10 @@ class Mixin:
     __cookie_options = {
         "secure": True,
         "httponly": True,
+        # rhbz#2097393
+        # Prevent a cookie to be sent on cross-site requests, allow it to be
+        # sent when navigating to pcs web UI from an external site.
+        "samesite": "Lax",
     }
 
     def initialize(self, session_storage: Storage):
@@ -48,7 +55,7 @@ class Mixin:
         if self.__session is None:
             raise Exception(
                 "Session is not set in session mixin. "
-                "Session probably has not been initialized in requst handler."
+                "Session probably has not been initialized in request handler."
             )
         return self.__session
 
@@ -102,6 +109,7 @@ class Mixin:
             self.sid_to_cookies()
         elif sign_rejection:
             self.__session = self.__storage.rejected_user(
-                self.__session.sid, user_auth_info.name,
+                self.__session.sid,
+                user_auth_info.name,
             )
             self.sid_to_cookies()
