@@ -8,8 +8,18 @@ from tornado.locks import Lock
 from tornado.web import Application
 
 from pcs import settings
-from pcs.daemon import log, ruby_pcsd, session, ssl, systemd
-from pcs.daemon.app import sinatra_ui, sinatra_remote, ui
+from pcs.daemon import (
+    log,
+    ruby_pcsd,
+    session,
+    ssl,
+    systemd,
+)
+from pcs.daemon.app import (
+    sinatra_remote,
+    sinatra_ui,
+    ui,
+)
 from pcs.daemon.app.common import RedirectHandler
 from pcs.daemon.env import prepare_env
 from pcs.daemon.http_server import HttpsServerManage
@@ -21,9 +31,9 @@ class SignalInfo:
     ioloop_started = False
 
 
-def handle_signal(incomming_signal, frame):
+def handle_signal(incoming_signal, frame):
     # pylint: disable=unused-argument
-    log.pcsd.warning("Caught signal: %s, shutting down", incomming_signal)
+    log.pcsd.warning("Caught signal: %s, shutting down", incoming_signal)
     if SignalInfo.server_manage:
         SignalInfo.server_manage.stop()
     if SignalInfo.ioloop_started:
@@ -54,7 +64,7 @@ def configure_app(
 ):
     def make_app(https_server_manage: HttpsServerManage):
         """
-        https_server_manage -- allows to controll the server (specifically
+        https_server_manage -- allows to control the server (specifically
             reload its SSL certificates). A relevant handler should get this
             object via the method `initialize`.
         """
@@ -66,9 +76,7 @@ def configure_app(
 
         if not disable_gui:
             routes.extend(
-                # old web ui by default
-                [(r"/", RedirectHandler, dict(url="/manage"))]
-                + [(r"/ui", RedirectHandler, dict(url="/ui/"))]
+                [(r"/(ui)?", RedirectHandler, dict(url="/ui/"))]
                 + ui.get_routes(
                     url_prefix="/ui/",
                     app_dir=os.path.join(public_dir, "ui"),
@@ -78,9 +86,7 @@ def configure_app(
                     ),
                     session_storage=session_storage,
                 )
-                + sinatra_ui.get_routes(
-                    session_storage, ruby_pcsd_wrapper, public_dir
-                )
+                + sinatra_ui.get_routes(session_storage, ruby_pcsd_wrapper)
             )
 
         return Application(routes, debug=debug)
