@@ -1,4 +1,3 @@
-from collections import namedtuple
 from typing import (
     Iterable,
     List,
@@ -9,34 +8,22 @@ from typing import (
 
 from lxml.etree import _Element
 
-from pcs.common import reports
-from pcs.common.reports.item import ReportItem, ReportItemList
+from pcs.common.reports.item import ReportItemList
 from pcs.lib.cib import nvpair
-from pcs.lib.cib.resource.bundle import (
-    TAG as TAG_BUNDLE,
-    is_bundle,
-    get_inner_resource as get_bundle_inner_resource,
-)
-from pcs.lib.cib.resource.clone import (
-    ALL_TAGS as TAG_CLONE_ALL,
-    get_inner_resource as get_clone_inner_resource,
-    get_parent_any_clone,
-    is_any_clone,
-    is_master,
-    is_promotable_clone,
-)
-from pcs.lib.cib.resource.group import (
-    TAG as TAG_GROUP,
-    is_group,
-    get_inner_resources as get_group_inner_resources,
-)
-from pcs.lib.cib.resource.primitive import (
-    TAG as TAG_PRIMITIVE,
-    is_primitive,
-)
 from pcs.lib.cib.tools import ElementSearcher
 from pcs.lib.xml_tools import find_parent
 
+from .bundle import TAG as TAG_BUNDLE
+from .bundle import get_inner_resource as get_bundle_inner_resource
+from .bundle import is_bundle
+from .clone import ALL_TAGS as TAG_CLONE_ALL
+from .clone import get_inner_resource as get_clone_inner_resource
+from .clone import is_any_clone
+from .group import TAG as TAG_GROUP
+from .group import get_inner_resources as get_group_inner_resources
+from .group import is_group
+from .primitive import TAG as TAG_PRIMITIVE
+from .primitive import is_primitive
 
 ALL_RESOURCE_XML_TAGS = sorted(
     TAG_CLONE_ALL + [TAG_GROUP, TAG_PRIMITIVE, TAG_BUNDLE]
@@ -158,6 +145,15 @@ def get_inner_resources(resource_el: _Element) -> List[_Element]:
     return []
 
 
+def is_resource(element: _Element) -> bool:
+    """
+    Return True for any resource, False otherwise, like meta_attributes element.
+
+    element -- element to check
+    """
+    return element.tag in ALL_RESOURCE_XML_TAGS
+
+
 def is_wrapper_resource(resource_el: _Element) -> bool:
     """
     Return True for resource_el of types that can contain other resource(s)
@@ -189,7 +185,7 @@ def get_parent_resource(resource_el: _Element) -> Optional[_Element]:
 
 def find_resources_to_enable(resource_el):
     """
-    Get resources to enable in order to enable specified resource succesfully
+    Get resources to enable in order to enable specified resource successfully
     etree resource_el -- resource element
     """
     if is_bundle(resource_el):
@@ -239,7 +235,7 @@ def disable(resource_el, id_provider):
 
 def find_resources_to_manage(resource_el):
     """
-    Get resources to manage to manage the specified resource succesfully
+    Get resources to manage to manage the specified resource successfully
     etree resource_el -- resource element
     """
     # If the resource_el is a primitive in a group, we set both the group and
@@ -255,7 +251,7 @@ def find_resources_to_manage(resource_el):
         +
         # its parents
         find_parent(resource_el, "resources").xpath(
-            # a master or a clone which contains a group, a primitve, or a
+            # a master or a clone which contains a group, a primitive, or a
             # grouped primitive with the specified id
             # OR
             # a group (in a clone, master, etc. - hence //) which contains a
@@ -263,14 +259,13 @@ def find_resources_to_manage(resource_el):
             # OR
             # a bundle which contains a primitive with the specified id
             """
-                (./master|./clone)[(group|group/primitive|primitive)[@id='{r}']]
+                (./master|./clone)[(group|group/primitive|primitive)[@id=$r]]
                 |
-                //group[primitive[@id='{r}']]
+                //group[primitive[@id=$r]]
                 |
-                ./bundle[primitive[@id='{r}']]
-            """.format(
-                r=res_id
-            )
+                ./bundle[primitive[@id=$r]]
+            """,
+            r=res_id,
         )
         +
         # its children
@@ -280,7 +275,7 @@ def find_resources_to_manage(resource_el):
 
 def find_resources_to_unmanage(resource_el):
     """
-    Get resources to unmanage to unmanage the specified resource succesfully
+    Get resources to unmanage to unmanage the specified resource successfully
     etree resource_el -- resource element
     """
     # resource hierarchy - specified resource - what to return
@@ -395,163 +390,3 @@ def find_resources_to_delete(resource_el: _Element) -> List[_Element]:
             if clone_el is not None:
                 result.insert(0, clone_el)
     return result
-
-
-def validate_move(resource_element, master):
-    """
-    Validate moving a resource to a node
-
-    etree resource_element -- the resource to be moved
-    bool master -- limit moving to the master role
-    """
-    report_list = []
-    analysis = _validate_move_ban_clear_analyzer(resource_element)
-
-    if analysis.is_bundle:
-        report_list.append(
-            ReportItem.error(
-                reports.messages.CannotMoveResourceBundle(
-                    resource_element.get("id")
-                )
-            )
-        )
-        return report_list
-
-    if (analysis.is_clone or analysis.is_in_clone) and not (
-        analysis.is_promotable_clone or analysis.is_in_promotable_clone
-    ):
-        report_list.append(
-            ReportItem.error(
-                reports.messages.CannotMoveResourceClone(
-                    resource_element.get("id")
-                )
-            )
-        )
-        return report_list
-
-    # Allow moving both promoted and demoted instances of promotable clones
-    # (analysis.is_promotable_clone). Do not allow to move promoted instances
-    # of promotables' inner resources (analysis.is_in_promotable_clone) as that
-    # would create a constraint for the promoted role of a group or a primitve
-    # which would not make sense if the group or primitive is later moved out
-    # of its promotable clone. To be consistent, we do not allow to move
-    # demoted instances of promotables' inner resources either. See
-    # rhbz#1875301 for details.
-    if not master and analysis.is_in_promotable_clone:
-        report_list.append(
-            ReportItem.error(
-                reports.messages.CannotMoveResourcePromotableInner(
-                    resource_element.get("id"),
-                    analysis.promotable_clone_id,
-                )
-            )
-        )
-    elif master and not analysis.is_promotable_clone:
-        report_list.append(
-            ReportItem.error(
-                reports.messages.CannotMoveResourceMasterResourceNotPromotable(
-                    resource_element.get("id"),
-                    promotable_id=analysis.promotable_clone_id,
-                )
-            )
-        )
-
-    return report_list
-
-
-def validate_ban(resource_element, master):
-    """
-    Validate banning a resource on a node
-
-    etree resource_element -- the resource to be banned
-    bool master -- limit banning to the master role
-    """
-    report_list = []
-    analysis = _validate_move_ban_clear_analyzer(resource_element)
-
-    if master and not analysis.is_promotable_clone:
-        report_list.append(
-            ReportItem.error(
-                reports.messages.CannotBanResourceMasterResourceNotPromotable(
-                    resource_element.get("id"),
-                    promotable_id=analysis.promotable_clone_id,
-                )
-            )
-        )
-
-    return report_list
-
-
-def validate_unmove_unban(resource_element, master):
-    """
-    Validate unmoving/unbanning a resource to/on nodes
-
-    etree resource_element -- the resource to be unmoved/unbanned
-    bool master -- limit unmoving/unbanning to the master role
-    """
-    report_list = []
-    analysis = _validate_move_ban_clear_analyzer(resource_element)
-
-    if master and not analysis.is_promotable_clone:
-        # pylint: disable=line-too-long
-        report_list.append(
-            ReportItem.error(
-                reports.messages.CannotUnmoveUnbanResourceMasterResourceNotPromotable(
-                    resource_element.get("id"),
-                    promotable_id=analysis.promotable_clone_id,
-                )
-            )
-        )
-
-    return report_list
-
-
-class _MoveBanClearAnalysis(
-    namedtuple(
-        "_MoveBanClearAnalysis",
-        [
-            "is_bundle",
-            "is_clone",
-            "is_in_clone",
-            "is_promotable_clone",
-            "is_in_promotable_clone",
-            "promotable_clone_id",
-        ],
-    )
-):
-    pass
-
-
-def _validate_move_ban_clear_analyzer(resource_element):
-    resource_is_bundle = False
-    resource_is_clone = False
-    resource_is_in_clone = False
-    resource_is_promotable_clone = False
-    resource_is_in_promotable_clone = False
-    promotable_clone_element = None
-
-    if is_bundle(resource_element):
-        resource_is_bundle = True
-    elif is_any_clone(resource_element):
-        resource_is_clone = True
-        if is_master(resource_element) or is_promotable_clone(resource_element):
-            resource_is_promotable_clone = True
-            promotable_clone_element = resource_element
-    elif get_parent_any_clone(resource_element) is not None:
-        parent_clone = get_parent_any_clone(resource_element)
-        resource_is_in_clone = True
-        if is_master(parent_clone) or is_promotable_clone(parent_clone):
-            resource_is_in_promotable_clone = True
-            promotable_clone_element = parent_clone
-    return _MoveBanClearAnalysis(
-        resource_is_bundle,
-        resource_is_clone,
-        resource_is_in_clone,
-        resource_is_promotable_clone,
-        resource_is_in_promotable_clone,
-        (
-            promotable_clone_element.get("id")
-            if promotable_clone_element is not None
-            else None
-        ),
-    )
