@@ -1,13 +1,12 @@
 """
-This module defines madatory and optional cib sections. It provides function for
-getting existing section from the cib (lxml) tree.
+This module defines mandatory and optional cib sections. It provides functions
+for getting existing sections from the cib (lxml) tree.
 """
 from pcs.common import reports
 from pcs.common.reports.item import ReportItem
 from pcs.lib.errors import LibraryError
 from pcs.lib.xml_tools import get_sub_element
 
-
 CONFIGURATION = "configuration"
 CONSTRAINTS = "configuration/constraints"
 CRM_CONFIG = "configuration/crm_config"
