@@ -2,7 +2,6 @@ from typing import (
     Iterable,
     Mapping,
     Optional,
-    Union,
 )
 
 from pcs import settings
@@ -13,11 +12,14 @@ from pcs.common.reports import (
     ReportProcessor,
 )
 from pcs.lib import node_communication_format
-from pcs.lib.tools import generate_binary_key
-from pcs.lib.cib.resource import guest_node, primitive, remote_node
+from pcs.lib.cib.resource import (
+    guest_node,
+    primitive,
+    remote_node,
+)
 from pcs.lib.cib.tools import (
-    IdProvider,
     ElementSearcher,
+    IdProvider,
     get_resources,
 )
 
@@ -31,21 +33,25 @@ from pcs.lib.communication.nodes import (
     RemoveFiles,
     ServiceAction,
 )
-from pcs.lib.communication.tools import (
-    run as run_com,
-    run_and_raise,
-)
+from pcs.lib.communication.tools import run as run_com
+from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.corosync.config_facade import ConfigFacade as CorosyncConfigFacade
-from pcs.lib.env import LibraryEnvironment
+from pcs.lib.env import (
+    LibraryEnvironment,
+    WaitType,
+)
 from pcs.lib.errors import LibraryError
 from pcs.lib.file.instance import FileInstance
 from pcs.lib.file.raw_file import raw_file_error_report
 from pcs.lib.node import get_existing_nodes_names_addrs
 from pcs.lib.pacemaker import state
 from pcs.lib.pacemaker.live import remove_node
-
-
-WaitType = Union[None, bool, int]
+from pcs.lib.resource_agent import (
+    ResourceAgentError,
+    ResourceAgentFacadeFactory,
+    resource_agent_error_to_report_item,
+)
+from pcs.lib.tools import generate_binary_key
 
 
 def _reports_skip_new_node(new_node_name, reason_type):
@@ -282,7 +288,7 @@ def node_add_remote(
         a resource agent metadata to the resource
     wait -- a flag for controlling waiting for pacemaker idle mechanism
     """
-    env.ensure_wait_satisfiable(wait)
+    wait_timeout = env.ensure_wait_satisfiable(wait)
 
     report_processor = env.report_processor
     cib = env.get_cib(
@@ -310,9 +316,13 @@ def node_add_remote(
         # shouldn't complain about errors related to corosync nodes
         report_processor.report_list(report_list)
 
-    resource_agent = remote_node.get_agent(
-        env.report_processor, env.cmd_runner()
-    )
+    try:
+        resource_agent_facade = ResourceAgentFacadeFactory(
+            env.cmd_runner(), report_processor
+        ).facade_from_parsed_name(remote_node.AGENT_NAME)
+    except ResourceAgentError as e:
+        report_processor.report(resource_agent_error_to_report_item(e))
+        raise LibraryError() from e
 
     existing_target_list = []
     if env.is_cib_live:
@@ -370,7 +380,7 @@ def node_add_remote(
     report_list = remote_node.validate_create(
         existing_nodes_names,
         existing_nodes_addrs,
-        resource_agent,
+        resource_agent_facade.metadata,
         node_name,
         node_addr,
         instance_attributes,
@@ -382,7 +392,7 @@ def node_add_remote(
     try:
         remote_resource_element = remote_node.create(
             env.report_processor,
-            resource_agent,
+            resource_agent_facade,
             get_resources(cib),
             id_provider,
             node_addr,
@@ -437,20 +447,20 @@ def node_add_remote(
             _reports_skip_new_node(node_name, "not_live_cib")
         )
 
-    env.push_cib(wait=wait)
-    if wait:
+    env.push_cib(wait_timeout=wait_timeout)
+    if wait_timeout >= 0:
         _ensure_resource_running(env, remote_resource_element.attrib["id"])
 
 
 def node_add_guest(
-    env,
+    env: LibraryEnvironment,
     node_name,
     resource_id,
     options,
     skip_offline_nodes=False,
     allow_incomplete_distribution=False,
     allow_pacemaker_remote_service_fail=False,
-    wait=False,
+    wait: WaitType = False,
 ):
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-locals
@@ -471,11 +481,12 @@ def node_add_guest(
         succeed
     mixed wait -- a flag for controlling waiting for pacemaker idle mechanism
     """
-    env.ensure_wait_satisfiable(wait)
+    wait_timeout = env.ensure_wait_satisfiable(wait)
 
     report_processor = env.report_processor
     cib = env.get_cib()
     id_provider = IdProvider(cib)
+    corosync_conf: Optional[CorosyncConfigFacade]
     if env.is_cib_live:
         corosync_conf = env.get_corosync_conf()
     else:
@@ -588,8 +599,8 @@ def node_add_guest(
             _reports_skip_new_node(node_name, "not_live_cib")
         )
 
-    env.push_cib(wait=wait)
-    if wait:
+    env.push_cib(wait_timeout=wait_timeout)
+    if wait_timeout >= 0:
         _ensure_resource_running(env, resource_id)
 
 
@@ -614,7 +625,7 @@ def _find_resources_to_remove(
         if report_processor.report(
             ReportItem(
                 severity=reports.item.get_severity(
-                    reports.codes.FORCE_REMOVE_MULTIPLE_NODES,
+                    reports.codes.FORCE,
                     allow_remove_multiple_nodes,
                 ),
                 message=reports.messages.MultipleResultsFound(
@@ -703,7 +714,7 @@ def node_remove_remote(
     callable remove_resource -- function for remove resource
     bool skip_offline_nodes -- a flag for ignoring when some nodes are offline
     bool allow_remove_multiple_nodes -- is a flag for allowing
-        remove unexpected multiple occurence of remote node for node_identifier
+        remove unexpected multiple occurrence of remote node for node_identifier
     bool allow_pacemaker_remote_service_fail -- is a flag for allowing
         successfully finish this command even if stoping/disabling
         pacemaker_remote not succeeded
@@ -748,12 +759,12 @@ def node_remove_remote(
 
 
 def node_remove_guest(
-    env,
+    env: LibraryEnvironment,
     node_identifier,
     skip_offline_nodes=False,
     allow_remove_multiple_nodes=False,
     allow_pacemaker_remote_service_fail=False,
-    wait=False,
+    wait: WaitType = False,
 ):
     """
     remove a resource representing remote node and destroy remote node
@@ -762,12 +773,12 @@ def node_remove_guest(
     string node_identifier -- node name, hostname or resource id
     bool skip_offline_nodes -- a flag for ignoring when some nodes are offline
     bool allow_remove_multiple_nodes -- is a flag for allowing
-        remove unexpected multiple occurence of remote node for node_identifier
+        remove unexpected multiple occurrence of remote node for node_identifier
     bool allow_pacemaker_remote_service_fail -- is a flag for allowing
         successfully finish this command even if stoping/disabling
         pacemaker_remote not succeeded
     """
-    env.ensure_wait_satisfiable(wait)
+    wait_timeout = env.ensure_wait_satisfiable(wait)
     cib = env.get_cib()
 
     resource_element_list = _find_resources_to_remove(
@@ -801,7 +812,7 @@ def node_remove_guest(
     for resource_element in resource_element_list:
         guest_node.unset_guest(resource_element)
 
-    env.push_cib(wait=wait)
+    env.push_cib(wait_timeout=wait_timeout)
 
     # remove node from pcmk caches
     if env.is_cib_live:
