@@ -1,9 +1,17 @@
 import re
 import xml.dom.minidom
-
-from typing import List, Any, Optional
+from typing import (
+    Any,
+    List,
+    Optional,
+)
 
 from pcs import utils
+from pcs.common import (
+    const,
+    pacemaker,
+)
+from pcs.common.str_tools import format_list_custom_last_separator
 
 # pylint: disable=not-callable
 
@@ -22,7 +30,7 @@ def parse_argv(argv, extra_options=None):
     while argv:
         found = False
         option = argv.pop(0)
-        for name in options:
+        for name in list(options):
             if option.startswith(name + "="):
                 options[name] = option.split("=", 1)[1]
                 found = True
@@ -33,7 +41,7 @@ def parse_argv(argv, extra_options=None):
     return options, argv
 
 
-def dom_rule_add(dom_element, options, rule_argv):
+def dom_rule_add(dom_element, options, rule_argv, cib_schema_version):
     # pylint: disable=too-many-branches
     """
     Commandline options: no options
@@ -42,16 +50,25 @@ def dom_rule_add(dom_element, options, rule_argv):
     if options.get("score") and options.get("score-attribute"):
         utils.err("can not specify both score and score-attribute")
     if options.get("score") and not utils.is_score(options["score"]):
-        # preserving legacy behaviour
-        print(
-            "Warning: invalid score '%s', setting score-attribute=pingd instead"
-            % options["score"]
+        utils.err("invalid score'{score}'".format(score=options["score"]))
+    if options.get("role"):
+        role = options["role"].capitalize()
+        utils.print_depracation_warning_for_legacy_roles(options["role"])
+        supported_roles = (
+            const.PCMK_ROLES_PROMOTED + const.PCMK_ROLES_UNPROMOTED
         )
-        options["score-attribute"] = "pingd"
-        options["score"] = None
-    if options.get("role") and options["role"] not in ["master", "slave"]:
-        utils.err(
-            "invalid role '%s', use 'master' or 'slave'" % options["role"]
+        if role not in supported_roles:
+            utils.err(
+                "invalid role '{role}', use {supported_roles}".format(
+                    role=options["role"],
+                    supported_roles=format_list_custom_last_separator(
+                        list(supported_roles), " or "
+                    ),
+                )
+            )
+        options["role"] = pacemaker.role.get_value_for_cib(
+            role,
+            cib_schema_version >= const.PCMK_NEW_ROLES_CIB_VERSION,
         )
     if options.get("id"):
         id_valid, id_error = utils.validate_xml_id(options["id"], "rule id")
@@ -67,21 +84,22 @@ def dom_rule_add(dom_element, options, rule_argv):
     if not rule_argv:
         utils.err("no rule expression was specified")
     try:
-        dom_rule = CibBuilder().build(
+        preprocessor = TokenPreprocessor()
+        dom_rule = CibBuilder(cib_schema_version).build(
             dom_element,
-            RuleParser().parse(TokenPreprocessor().run(rule_argv)),
+            RuleParser().parse(preprocessor.run(rule_argv)),
             options.get("id"),
         )
     except SyntaxError as e:
         utils.err(
             "'%s' is not a valid rule expression: %s" % (" ".join(rule_argv), e)
         )
-    except UnexpectedEndOfInput as e:
+    except UnexpectedEndOfInput:
         utils.err(
             "'%s' is not a valid rule expression: unexpected end of rule"
             % " ".join(rule_argv)
         )
-    except (ParserException, CibBuilderException) as e:
+    except (ParserException, CibBuilderException):
         utils.err("'%s' is not a valid rule expression" % " ".join(rule_argv))
 
     # add options into rule xml
@@ -279,6 +297,31 @@ class ExportAsExpression:
         return attributes
 
 
+def has_node_attr_expr_with_type_integer(rule_tree):
+    if isinstance(rule_tree, SymbolOperator):
+        if rule_tree.symbol_id in RuleParser.boolean_list:
+            return any(
+                has_node_attr_expr_with_type_integer(child)
+                for child in rule_tree.children
+            )
+        if (
+            rule_tree.symbol_id in RuleParser.date_comparison_list
+            and rule_tree.children[0].value == "date"
+            and rule_tree.children[1].is_literal()
+        ) or (
+            isinstance(rule_tree, SymbolTypeDateCommon)
+            and rule_tree.date_value_class == DateSpecValue
+        ):
+            return False
+        if isinstance(rule_tree, SymbolPrefix):
+            return False
+        child = rule_tree.children[1]
+        if isinstance(child, SymbolType) and child.symbol_id == "integer":
+            return True
+        return False
+    return False
+
+
 # generic parser
 
 
@@ -376,7 +419,7 @@ class SymbolType(SymbolPrefix):
     value_re = None
 
     def null_denotation(self):
-        super(SymbolType, self).null_denotation()
+        super().null_denotation()
         if self.value_re and not self.value_re.match(self.children[0].value):
             raise SyntaxError(
                 "invalid %s value '%s'"
@@ -434,7 +477,7 @@ class SymbolTernary(SymbolOperator):
 
 class SymbolTable:
     def __init__(self):
-        self.table = dict()
+        self.table = {}
 
     def has_symbol(self, symbol_id):
         return symbol_id in self.table
@@ -472,7 +515,7 @@ class Parser:
     def __init__(self):
         self.current_symbol = None
         self.current_symbol_index = -1
-        self.program = list()
+        self.program = []
         self.symbol_table = SymbolTable()
         self.new_symbol_literal(SymbolBase.LITERAL)
         self.new_symbol_literal(SymbolBase.END)
@@ -516,7 +559,7 @@ class Parser:
         return symbol_class
 
     def symbolize(self, program):
-        symbolized_program = list()
+        symbolized_program = []
         literal_class = self.symbol_table.get_symbol(SymbolBase.LITERAL)
         for token in program:
             if self.symbol_table.has_symbol(token) and (
@@ -603,7 +646,7 @@ class DateCommonValue:
     KEYWORD: Optional[str] = None
 
     def __init__(self, parts_string, keyword=None):
-        self.parts = dict()
+        self.parts = {}
         for part in parts_string.split():
             if not self.accepts_part(part):
                 raise SyntaxError("unexpected '%s' in %s" % (part, keyword))
@@ -661,7 +704,7 @@ class DateSpecValue(DateCommonValue):
     }
 
     def __init__(self, parts_string):
-        super(DateSpecValue, self).__init__(parts_string, self.KEYWORD)
+        super().__init__(parts_string, self.KEYWORD)
 
     def validate(self):
         for name, value in self.parts.items():
@@ -699,7 +742,7 @@ class DateDurationValue(DateCommonValue):
     KEYWORD = "duration"
 
     def __init__(self, parts_string):
-        super(DateDurationValue, self).__init__(parts_string, self.KEYWORD)
+        super().__init__(parts_string, self.KEYWORD)
 
     def validate(self):
         for name, value in self.parts.items():
@@ -732,12 +775,12 @@ class SymbolTernaryInRange(SymbolTernary):
     symbol_second_id = "to"
 
     def is_allowed_child(self, child_symbol, child_position):
-        return super(SymbolTernaryInRange, self).is_allowed_child(
-            child_symbol, child_position
-        ) and (child_position != 0 or child_symbol.value == "date")
+        return super().is_allowed_child(child_symbol, child_position) and (
+            child_position != 0 or child_symbol.value == "date"
+        )
 
     def left_denotation(self, left):
-        super(SymbolTernaryInRange, self).left_denotation(left)
+        super().left_denotation(left)
         for child in self.children[1:]:
             if child.is_literal() and not utils.is_iso8601_date(child.value):
                 raise SyntaxError(
@@ -752,12 +795,12 @@ class RuleParser(Parser):
     date_comparison_list = ["gt", "lt", "in_range"]
     prefix_list = ["defined", "not_defined"]
     boolean_list = ["and", "or"]
-    simple_type_list = ["string", "integer", "version"]
+    simple_type_list = ["string", "integer", "number", "version"]
     parenthesis_open = "("
     parenthesis_close = ")"
 
     def __init__(self):
-        super(RuleParser, self).__init__()
+        super().__init__()
 
         for operator in RuleParser.comparison_list:
             if operator == "in_range":
@@ -780,7 +823,20 @@ class RuleParser(Parser):
         for operator in RuleParser.simple_type_list:
             symbol_class = self.new_symbol_type(operator, 70)
         self.symbol_table.get_symbol("integer").value_re = re.compile(
-            r"^-?\d+$"
+            r"^[-+]?\d+$"
+        )
+        # rhbz#1869399
+        # Originally, pacemaker only supported 'number', treated it as an
+        # integer and documented it as 'integer'. With CIB schema 3.5.0+,
+        # 'integer' is supported as well. With crm_feature_set 3.5.0+, 'number'
+        # is treated as a floating point number.
+        # Since pcs never supported 'number' until the above changes in
+        # pacemaker happened and pacemaker was able to handle floating point
+        # numbers before (even though truncating them to integers), we'll just
+        # check for a float here. If that's not good enough, we can fix it
+        # later and validate the value as integer when crm_feature_set < 3.5.0.
+        self.symbol_table.get_symbol("number").value_re = re.compile(
+            r"^[-+]?(\d+|(\d*\.\d+)|(\d+\.\d*))([eE][+-]?\d+)?$"
         )
         self.symbol_table.get_symbol("version").value_re = re.compile(
             r"^\d+(\.\d+)*$"
@@ -802,7 +858,7 @@ class RuleParser(Parser):
         )
 
     def parse(self, program):
-        syntactic_tree = super(RuleParser, self).parse(program)
+        syntactic_tree = super().parse(program)
         if syntactic_tree.is_literal() or (
             isinstance(syntactic_tree, SymbolType)
             and not (
@@ -835,6 +891,9 @@ class RuleParser(Parser):
 
 
 class CibBuilder:
+    def __init__(self, cib_schema_version):
+        self.cib_schema_version = cib_schema_version
+
     def build(self, dom_element, syntactic_tree, rule_id=None):
         dom_rule = self.add_element(
             dom_element,
@@ -890,14 +949,21 @@ class CibBuilder:
         if not isinstance(syntactic_tree, SymbolPrefix):
             child = syntactic_tree.children[1]
             if isinstance(child, SymbolType):
-                dom_expression.setAttribute(
-                    "type",
-                    (
-                        "number"
-                        if child.symbol_id == "integer"
-                        else child.symbol_id
-                    ),
-                )
+                # rhbz#1869399
+                # Pcs was always accepting 'integer', while CIB was only
+                # supporting 'number' (and 'string' and 'version'). Pacemaker
+                # was documenting it as 'integer' and was treating it as
+                # integer (not float). With CIB schema 3.5.0, both 'integer'
+                # and 'number' are accepted by CIB. For older schemas, we turn
+                # 'integer' to 'number'.
+                if (
+                    self.cib_schema_version
+                    < const.PCMK_RULES_NODE_ATTR_EXPR_WITH_INT_TYPE_CIB_VERSION
+                    and child.symbol_id == "integer"
+                ):
+                    dom_expression.setAttribute("type", "number")
+                else:
+                    dom_expression.setAttribute("type", child.symbol_id)
                 child = child.children[0]
             dom_expression.setAttribute("value", child.value)
 
@@ -972,9 +1038,7 @@ class InvalidSyntacticTree(CibBuilderException):
 
 class TokenPreprocessor:
     def run(self, token_list):
-        return self.convert_legacy_date(
-            self.join_date_common(self.separate_parenthesis(token_list))
-        )
+        return self.join_date_common(self.separate_parenthesis(token_list))
 
     @staticmethod
     def separate_parenthesis(input_list):
@@ -1011,11 +1075,6 @@ class TokenPreprocessor:
             if in_datecommon:
                 if DateCommonValue.accepts_part(token):
                     token_parts.append(token)
-                elif (
-                    token == "operation=date_spec"
-                    and token_parts[0] == DateSpecValue.KEYWORD
-                ):
-                    pass  # gracefully ignoring for backwards compatibility
                 else:
                     in_datecommon = False
                     output_list.append(token_parts[0])
@@ -1033,40 +1092,3 @@ class TokenPreprocessor:
             if len(token_parts) > 1:
                 output_list.append(" ".join(token_parts[1:]))
         return output_list
-
-    @staticmethod
-    def convert_legacy_date(input_list):
-        output_list = []
-        in_date = False
-        date_start = ""
-        date_end = ""
-        token_parts = []
-        for token in input_list:
-            if in_date:
-                token_parts.append(token)
-                if token.startswith("start="):
-                    date_start = token[len("start=") :]
-                elif token.startswith("end="):
-                    date_end = token[len("end=") :]
-                else:
-                    if token == "gt" and date_start and not date_end:
-                        output_list.extend(["date", "gt", date_start])
-                    elif token == "lt" and not date_start and date_end:
-                        output_list.extend(["date", "lt", date_end])
-                    elif token == "in_range" and date_start and date_end:
-                        output_list.extend(
-                            ["date", "in_range", date_start, "to", date_end]
-                        )
-                    else:
-                        output_list.extend(token_parts)
-                    token_parts = []
-                    date_start = date_end = ""
-                    in_date = False
-            elif token == "date":
-                token_parts = ["date"]
-                in_date = True
-            else:
-                output_list.append(token)
-        if token_parts:
-            output_list.extend(token_parts)
-        return output_list
