@@ -1,13 +1,13 @@
 import inspect
 from unittest import TestCase
 
+from pcs.cli.reports import messages as cli_messages
 from pcs.common import file_type_codes
 from pcs.common.reports import (
+    const,
     item,
     messages,
-    const,
 )
-from pcs.cli.reports import messages as cli_messages
 
 
 class AllClassesTested(TestCase):
@@ -76,15 +76,15 @@ class CannotUnmoveUnbanResourceMasterResourceNotPromotable(
                 "R", "P"
             ),
             (
-                "when specifying --master you must use the promotable clone id "
-                "(P)"
+                "when specifying --promoted you must use the promotable clone "
+                "id (P)"
             ),
         )
 
     def test_without_promotable_id(self):
         self.assert_message(
             messages.CannotUnmoveUnbanResourceMasterResourceNotPromotable("R"),
-            "when specifying --master you must use the promotable clone id",
+            "when specifying --promoted you must use the promotable clone id",
         )
 
 
@@ -93,15 +93,15 @@ class CannotBanResourceMasterResourceNotPromotable(CliReportMessageTestBase):
         self.assert_message(
             messages.CannotBanResourceMasterResourceNotPromotable("R", "P"),
             (
-                "when specifying --master you must use the promotable clone id "
-                "(P)"
+                "when specifying --promoted you must use the promotable clone "
+                "id (P)"
             ),
         )
 
     def test_without_promotable_id(self):
         self.assert_message(
             messages.CannotBanResourceMasterResourceNotPromotable("R"),
-            "when specifying --master you must use the promotable clone id",
+            "when specifying --promoted you must use the promotable clone id",
         )
 
 
@@ -110,15 +110,27 @@ class CannotMoveResourceMasterResourceNotPromotable(CliReportMessageTestBase):
         self.assert_message(
             messages.CannotMoveResourceMasterResourceNotPromotable("R", "P"),
             (
-                "when specifying --master you must use the promotable clone id "
-                "(P)"
+                "when specifying --promoted you must use the promotable clone "
+                "id (P)"
             ),
         )
 
     def test_without_promotable_id(self):
         self.assert_message(
             messages.CannotMoveResourceMasterResourceNotPromotable("R"),
-            "when specifying --master you must use the promotable clone id",
+            "when specifying --promoted you must use the promotable clone id",
+        )
+
+
+class CannotMoveResourceNotRunning(CliReportMessageTestBase):
+    def test_success(self):
+        self.assert_message(
+            messages.CannotMoveResourceNotRunning("R"),
+            (
+                "It is not possible to move resource 'R' as it is not running "
+                "at the moment, use 'pcs resource move-with-constraint' or "
+                "'pcs constraint location' commands instead"
+            ),
         )
 
 
@@ -540,6 +552,27 @@ class UnableToGetAgentMetadata(CliReportMessageTestBase):
         )
 
 
+class InvalidResourceAgentName(CliReportMessageTestBase):
+    def test_success(self):
+        self.assert_message(
+            messages.InvalidResourceAgentName(":name"),
+            "Invalid resource agent name ':name'. Use standard:provider:type "
+            "when standard is 'ocf' or standard:type otherwise. List of standards "
+            "and providers can be obtained by using commands 'pcs resource "
+            "standards' and 'pcs resource providers'.",
+        )
+
+
+class InvalidStonithAgentName(CliReportMessageTestBase):
+    def test_success(self):
+        self.assert_message(
+            messages.InvalidStonithAgentName("fence:name"),
+            "Invalid stonith agent name 'fence:name'. Agent name cannot contain "
+            "the ':' character, do not use the 'stonith:' prefix. List of agents "
+            "can be obtained by using command 'pcs stonith list'.",
+        )
+
+
 class HostAlreadyInClusterConfig(CliReportMessageTestBase):
     def test_message(self):
         self.assert_message(
@@ -585,3 +618,30 @@ class StonithRestartlessUpdateUnableToPerform(CliReportMessageTestBase):
             report_msg,
             f"{report_msg.message}, please use command 'pcs stonith update' instead",
         )
+
+
+class ResourceStonithCommandsMismatch(CliReportMessageTestBase):
+    def test_no_cmd(self):
+        report_msg = messages.ResourceStonithCommandsMismatch("element type")
+        self.assert_message(
+            report_msg,
+            report_msg.message,
+        )
+
+    def test_unknown_cmd(self):
+        report_msg = messages.ResourceStonithCommandsMismatch(
+            "element type", const.PCS_COMMAND_RESOURCE_CREATE
+        )
+        self.assert_message(
+            report_msg,
+            report_msg.message,
+        )
+
+    def test_use_instead(self):
+        report_msg = messages.ResourceStonithCommandsMismatch(
+            "element type", const.PCS_COMMAND_STONITH_CREATE
+        )
+        self.assert_message(
+            report_msg,
+            f"{report_msg.message} Use 'pcs stonith create' command instead.",
+        )
