@@ -1,20 +1,21 @@
 from functools import partial
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
+
 from lxml import etree
 
+from pcs.lib.cib.resource import primitive
+from pcs.lib.cib.tools import IdProvider
+from pcs.lib.resource_agent import ResourceAgentName
+
 from pcs_test.tools.assertions import assert_xml_equal
 
-from pcs.lib.resource_agent import CrmAgent
-from pcs.lib.cib.resource import primitive
-from pcs.lib.cib.tools import IdProvider
-
 
 class FindPrimitivesByAgent(TestCase):
+    # pylint: disable=protected-access
     def setUp(self):
-        self.agent = mock.MagicMock(spec_set=CrmAgent)
-        self.agent.get_standard.return_value = "standard"
-        self.agent.get_provider.return_value = "provider"
-        self.agent.get_type.return_value = "agent_type"
         self.resources_section = etree.fromstring(
             """
         <resources>
@@ -58,10 +59,13 @@ class FindPrimitivesByAgent(TestCase):
         )
 
     def test_stonith(self):
-        self.agent.get_standard.return_value = "stonith"
-        self.agent.get_provider.return_value = ""
-        results = primitive.find_primitives_by_agent(
-            self.resources_section, self.agent
+        results = primitive._find_primitives_by_agent(
+            self.resources_section,
+            ResourceAgentName(
+                "stonith",
+                None,
+                "agent_type",
+            ),
         )
         expected_results = [
             '<primitive class="stonith" type="agent_type" id="r1"/>',
@@ -72,8 +76,13 @@ class FindPrimitivesByAgent(TestCase):
             assert_xml_equal(expected_results[i], etree.tostring(res).decode())
 
     def test_with_provider(self):
-        results = primitive.find_primitives_by_agent(
-            self.resources_section, self.agent
+        results = primitive._find_primitives_by_agent(
+            self.resources_section,
+            ResourceAgentName(
+                "standard",
+                "provider",
+                "agent_type",
+            ),
         )
         expected_results = [
             """<primitive
