@@ -1,20 +1,23 @@
 import logging
 from contextlib import contextmanager
-from unittest import mock, TestCase
 from functools import partial
-from lxml import etree
+from unittest import (
+    TestCase,
+    mock,
+)
 
-from pcs_test.tools.assertions import assert_raise_library_error
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-from pcs_test.tools.misc import create_patcher
+from lxml import etree
 
 from pcs.common.reports import ReportItemSeverity as severity
 from pcs.common.reports import codes as report_codes
 from pcs.lib.cib.tools import IdProvider
+from pcs.lib.commands import node as lib
 from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
 
-from pcs.lib.commands import node as lib
+from pcs_test.tools.assertions import assert_raise_library_error
+from pcs_test.tools.custom_mock import MockLibraryReportProcessor
+from pcs_test.tools.misc import create_patcher
 
 # pylint: disable=protected-access
 
@@ -132,7 +135,7 @@ class StandbyMaintenancePassParametersAll(StandbyMaintenancePassParameters):
         )
 
 
-class SetInstaceAttrsBase(TestCase):
+class SetInstanceAttrsBase(TestCase):
     node_count = 2
 
     def setUp(self):
@@ -165,7 +168,7 @@ class SetInstaceAttrsBase(TestCase):
 
 @patch_command("update_node_instance_attrs")
 @patch_command("get_local_node_name")
-class SetInstaceAttrsLocal(SetInstaceAttrsBase):
+class SetInstanceAttrsLocal(SetInstanceAttrsBase):
     node_count = 2
 
     def test_not_possible_with_cib_file(self, mock_name, mock_attrs):
@@ -198,7 +201,7 @@ class SetInstaceAttrsLocal(SetInstaceAttrsBase):
 
 
 @patch_command("update_node_instance_attrs")
-class SetInstaceAttrsAll(SetInstaceAttrsBase):
+class SetInstanceAttrsAll(SetInstanceAttrsBase):
     node_count = 2
 
     def test_success(self, mock_attrs):
@@ -215,7 +218,7 @@ class SetInstaceAttrsAll(SetInstaceAttrsBase):
 
 
 @patch_command("update_node_instance_attrs")
-class SetInstaceAttrsList(SetInstaceAttrsBase):
+class SetInstanceAttrsList(SetInstanceAttrsBase):
     node_count = 4
 
     def test_success(self, mock_attrs):
@@ -260,10 +263,10 @@ class CibRunnerNodes(TestCase):
     @patch_env("cmd_runner", lambda self: "mocked cmd_runner")
     @patch_env("ensure_wait_satisfiable")
     @patch_command("ClusterState")
-    @patch_command("get_cluster_status_xml")
-    def test_wire_together_all_expected_dependecies(
+    @patch_env("get_cluster_state")
+    def test_wire_together_all_expected_dependencies(
         self,
-        get_cluster_status_xml,
+        get_cluster_state,
         cluster_state,
         ensure_wait_satisfiable,
         push_cib,
@@ -271,18 +274,19 @@ class CibRunnerNodes(TestCase):
         cluster_state.return_value = mock.MagicMock(
             node_section=mock.MagicMock(nodes="nodes")
         )
-        get_cluster_status_xml.return_value = "mock get_cluster_status_xml"
+        get_cluster_state.return_value = "mock get_cluster_state"
         wait = 10
+        ensure_wait_satisfiable.return_value = wait
 
         with lib.cib_runner_nodes(self.env, wait) as (cib, runner, nodes):
             self.assertEqual(cib, "mocked cib")
             self.assertEqual(runner, "mocked cmd_runner")
             self.assertEqual(nodes, "nodes")
             ensure_wait_satisfiable.assert_called_once_with(wait)
-            get_cluster_status_xml.assert_called_once_with("mocked cmd_runner")
-            cluster_state.assert_called_once_with("mock get_cluster_status_xml")
+            get_cluster_state.assert_called_once_with()
+            cluster_state.assert_called_once_with("mock get_cluster_state")
 
-        push_cib.assert_called_once_with(wait=wait)
+        push_cib.assert_called_once_with(wait_timeout=wait)
 
     @patch_env("ensure_wait_satisfiable", mock.Mock(side_effect=LibraryError))
     def test_raises_when_wait_is_not_satisfiable(self, push_cib):
