@@ -1,11 +1,12 @@
 from unittest import TestCase
+
 from lxml import etree
 
-from pcs_test.tools.bin_mock import get_mock_settings
 from pcs_test.tools.assertions import AssertPcsMixin
+from pcs_test.tools.bin_mock import get_mock_settings
 from pcs_test.tools.cib import get_assert_pcs_effect_mixin
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
-    get_test_resource as rc,
     get_tmp_file,
     outdent,
     write_file_to_tmpfile,
@@ -15,7 +16,7 @@ from pcs_test.tools.pcs_runner import PcsRunner
 # pylint: disable=line-too-long
 # pylint: disable=too-many-public-methods
 
-ERRORS_HAVE_OCURRED = (
+ERRORS_HAVE_OCCURRED = (
     "Error: Errors have occurred, therefore pcs is unable to continue\n"
 )
 
@@ -185,8 +186,8 @@ class BundleCreate(BundleCreateCommon):
                     </bundle>
                 </resources>
             """,
-            "Warning: container option 'masters' is deprecated and should not "
-            "be used, use 'promoted-max' instead\n",
+            "Deprecation Warning: container option 'masters' is deprecated and "
+            "should not be used, use 'promoted-max' instead\n",
         )
 
     def test_deprecated_masters_and_promoted_max(self):
@@ -195,11 +196,11 @@ class BundleCreate(BundleCreateCommon):
                 resource bundle create B1
                 container docker image=pcs:test masters=0 promoted-max=0
             """.split(),
-            "Error: Only one of container options 'masters' and 'promoted-max' "
-            "can be used\n"
-            + ERRORS_HAVE_OCURRED
-            + "Warning: container option 'masters' is deprecated and should "
-            "not be used, use 'promoted-max' instead\n",
+            "Error: Only one of container options 'masters' and "
+            "'promoted-max' can be used\n"
+            "Deprecation Warning: container option 'masters' is deprecated and "
+            "should not be used, use 'promoted-max' instead\n"
+            + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_missing_args_1(self):
@@ -218,14 +219,14 @@ class BundleCreate(BundleCreateCommon):
         self.assert_pcs_fail_regardless_of_force(
             "resource bundle create B1".split(),
             "Error: '' is not a valid container type value, use 'docker', "
-            "'podman', 'rkt'\n" + ERRORS_HAVE_OCURRED,
+            "'podman', 'rkt'\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_missing_required(self):
         self.assert_pcs_fail_regardless_of_force(
             "resource bundle create B1 container docker".split(),
             "Error: required container option 'image' is missing\n"
-            + ERRORS_HAVE_OCURRED,
+            + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_on_unknown_option(self):
@@ -237,7 +238,7 @@ class BundleCreate(BundleCreateCommon):
             "Error: invalid container option 'extra', allowed options are: "
             "'image', 'masters', 'network', 'options', 'promoted-max', "
             "'replicas', 'replicas-per-host', 'run-command', use --force "
-            "to override\n" + ERRORS_HAVE_OCURRED,
+            "to override\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_unknown_option_forced(self):
@@ -250,7 +251,12 @@ class BundleCreate(BundleCreateCommon):
                 resource bundle create B1 container docker image=pcs:test
                 extra=option --force
             """.split(),
-            stdout_start="Error: Unable to update cib\n",
+            stdout_start=(
+                "Warning: invalid container option 'extra', allowed options "
+                "are: 'image', 'masters', 'network', 'options', 'promoted-max',"
+                " 'replicas', 'replicas-per-host', 'run-command'\n"
+                "Error: Unable to update cib\n"
+            ),
         )
 
     def test_more_errors(self):
@@ -263,7 +269,7 @@ class BundleCreate(BundleCreateCommon):
                 Error: 'x' is not a valid replicas value, use a positive integer
                 """
             )
-            + ERRORS_HAVE_OCURRED,
+            + ERRORS_HAVE_OCCURRED,
         )
 
     def assert_no_options(self, keyword):
@@ -494,16 +500,16 @@ class BundleUpdate(BundleCreateCommon):
                     </bundle>
                 </resources>
             """,
-            "Warning: container option 'masters' is deprecated and should not "
-            "be used, use 'promoted-max' instead\n",
+            "Deprecation Warning: container option 'masters' is deprecated and "
+            "should not be used, use 'promoted-max' instead\n",
         )
 
     def test_delete_masters(self):
         self.fixture_bundle("B")
         self.assert_pcs_success(
             "resource bundle update B container masters=2".split(),
-            "Warning: container option 'masters' is deprecated and should not "
-            "be used, use 'promoted-max' instead\n",
+            "Deprecation Warning: container option 'masters' is deprecated and "
+            "should not be used, use 'promoted-max' instead\n",
         )
         self.assert_effect(
             "resource bundle update B container masters=".split(),
@@ -529,11 +535,10 @@ class BundleUpdate(BundleCreateCommon):
         )
         self.assert_pcs_fail(
             "resource bundle update B container masters=2".split(),
+            "Deprecation Warning: container option 'masters' is deprecated "
+            "and should not be used, use 'promoted-max' instead\n"
             "Error: Cannot set container option 'masters' because container "
-            "option 'promoted-max' is already set\n"
-            + ERRORS_HAVE_OCURRED
-            + "Warning: container option 'masters' is deprecated and should "
-            "not be used, use 'promoted-max' instead\n",
+            "option 'promoted-max' is already set\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_masters_set_after_promoted_max_with_remove(self):
@@ -550,29 +555,30 @@ class BundleUpdate(BundleCreateCommon):
                     </bundle>
                 </resources>
             """,
-            "Warning: container option 'masters' is deprecated and should not "
-            "be used, use 'promoted-max' instead\n",
+            "Deprecation Warning: container option 'masters' is deprecated and "
+            "should not be used, use 'promoted-max' instead\n",
         )
 
     def test_promoted_max_set_after_masters(self):
         self.fixture_bundle("B")
         self.assert_pcs_success(
             "resource bundle update B container masters=2".split(),
-            "Warning: container option 'masters' is deprecated and should not "
-            "be used, use 'promoted-max' instead\n",
+            "Deprecation Warning: container option 'masters' is deprecated and "
+            "should not be used, use 'promoted-max' instead\n",
         )
         self.assert_pcs_fail(
             "resource bundle update B container promoted-max=3".split(),
             "Error: Cannot set container option 'promoted-max' because "
-            "container option 'masters' is already set\n" + ERRORS_HAVE_OCURRED,
+            "container option 'masters' is already set\n"
+            + ERRORS_HAVE_OCCURRED,
         )
 
     def test_promoted_max_set_after_masters_with_remove(self):
         self.fixture_bundle("B")
         self.assert_pcs_success(
             "resource bundle update B container masters=2".split(),
-            "Warning: container option 'masters' is deprecated and should not "
-            "be used, use 'promoted-max' instead\n",
+            "Deprecation Warning: container option 'masters' is deprecated and "
+            "should not be used, use 'promoted-max' instead\n",
         )
         self.assert_effect(
             "resource bundle update B container masters= promoted-max=3".split(),
@@ -593,7 +599,7 @@ class BundleUpdate(BundleCreateCommon):
             "Error: invalid container option 'extra', allowed options are: "
             "'image', 'masters', 'network', 'options', 'promoted-max', "
             "'replicas', 'replicas-per-host', 'run-command', use --force "
-            "to override\n" + ERRORS_HAVE_OCURRED,
+            "to override\n" + ERRORS_HAVE_OCCURRED,
         )
         # Test that pcs allows to specify options it does not know about. This
         # ensures some kind of forward compatibility, so the user will be able
@@ -601,7 +607,12 @@ class BundleUpdate(BundleCreateCommon):
         # supported by pacemaker and so the command fails.
         self.assert_pcs_fail(
             "resource bundle update B container extra=option --force".split(),
-            stdout_start="Error: Unable to update cib\n",
+            stdout_start=(
+                "Warning: invalid container option 'extra', allowed options "
+                "are: 'image', 'masters', 'network', 'options', 'promoted-max',"
+                " 'replicas', 'replicas-per-host', 'run-command'\n"
+                "Error: Unable to update cib\n",
+            ),
         )
 
         # no force needed when removing an unknown option
@@ -659,7 +670,7 @@ class BundleShow(TestCase, AssertPcsMixin):
             "resource config B1".split(),
             outdent(
                 """\
-             Bundle: B1
+            Bundle: B1
               Docker: image=pcs:test
             """
             ),
@@ -684,8 +695,8 @@ class BundleShow(TestCase, AssertPcsMixin):
             "resource config B1".split(),
             outdent(
                 """\
-             Bundle: B1
-              Docker: image=pcs:test options="a b c" promoted-max=2 replicas=4
+            Bundle: B1
+              Docker: image=pcs:test replicas=4 promoted-max=2 options="a b c"
             """
             ),
         )
@@ -702,7 +713,7 @@ class BundleShow(TestCase, AssertPcsMixin):
             "resource config B1".split(),
             outdent(
                 """\
-             Bundle: B1
+            Bundle: B1
               Docker: image=pcs:test
               Network: control-port=12345 host-interface=eth0 host-netmask=24
             """
@@ -722,11 +733,11 @@ class BundleShow(TestCase, AssertPcsMixin):
             "resource config B1".split(),
             outdent(
                 """\
-             Bundle: B1
+            Bundle: B1
               Docker: image=pcs:test
               Port Mapping:
-               internal-port=2002 port=2000 (B1-port-map-1001)
-               range=3000-3300 (B1-port-map-3000-3300)
+                port=2000 internal-port=2002 (B1-port-map-1001)
+                range=3000-3300 (B1-port-map-3000-3300)
             """
             ),
         )
@@ -745,11 +756,11 @@ class BundleShow(TestCase, AssertPcsMixin):
             "resource config B1".split(),
             outdent(
                 """\
-             Bundle: B1
+            Bundle: B1
               Docker: image=pcs:test
               Storage Mapping:
-               source-dir=/tmp/docker1a target-dir=/tmp/docker1b (B1-storage-map)
-               source-dir=/tmp/docker2a target-dir=/tmp/docker2b (my-storage-map)
+                source-dir=/tmp/docker1a target-dir=/tmp/docker1b (B1-storage-map)
+                source-dir=/tmp/docker2a target-dir=/tmp/docker2b (my-storage-map)
             """
             ),
         )
@@ -765,9 +776,10 @@ class BundleShow(TestCase, AssertPcsMixin):
             "resource config B1".split(),
             outdent(
                 """\
-             Bundle: B1
+            Bundle: B1
               Docker: image=pcs:test
-              Meta Attrs: target-role=Stopped
+              Meta Attributes: B1-meta_attributes
+                target-role=Stopped
             """
             ),
         )
@@ -787,11 +799,14 @@ class BundleShow(TestCase, AssertPcsMixin):
             "resource config B1".split(),
             outdent(
                 """\
-             Bundle: B1
+            Bundle: B1
               Docker: image=pcs:test
               Network: control-port=1234
               Resource: A (class=ocf provider=pacemaker type=Dummy)
-               Operations: monitor interval=10s timeout=20s (A-monitor-interval-10s)
+                Operations:
+                  monitor: A-monitor-interval-10s
+                    interval=10s
+                    timeout=20s
             """
             ),
         )
@@ -838,18 +853,23 @@ class BundleShow(TestCase, AssertPcsMixin):
             "resource config B1".split(),
             outdent(
                 """\
-             Bundle: B1
-              Docker: image=pcs:test options="a b c" promoted-max=2 replicas=4
+            Bundle: B1
+              Docker: image=pcs:test replicas=4 promoted-max=2 options="a b c"
               Network: control-port=12345 host-interface=eth0 host-netmask=24
               Port Mapping:
-               internal-port=2002 port=2000 (B1-port-map-1001)
-               range=3000-3300 (B1-port-map-3000-3300)
+                port=2000 internal-port=2002 (B1-port-map-1001)
+                range=3000-3300 (B1-port-map-3000-3300)
               Storage Mapping:
-               source-dir=/tmp/docker1a target-dir=/tmp/docker1b (B1-storage-map)
-               source-dir=/tmp/docker2a target-dir=/tmp/docker2b (my-storage-map)
-              Meta Attrs: is-managed=false target-role=Stopped
+                source-dir=/tmp/docker1a target-dir=/tmp/docker1b (B1-storage-map)
+                source-dir=/tmp/docker2a target-dir=/tmp/docker2b (my-storage-map)
+              Meta Attributes: B1-meta_attributes
+                is-managed=false
+                target-role=Stopped
               Resource: A (class=ocf provider=pacemaker type=Dummy)
-               Operations: monitor interval=10s timeout=20s (A-monitor-interval-10s)
+                Operations:
+                  monitor: A-monitor-interval-10s
+                    interval=10s
+                    timeout=20s
             """
             ),
         )
