@@ -1,23 +1,26 @@
 import re
-from unittest import mock, TestCase
-
-from pcs_test.tier1.cib_resource.common import ResourceTest
-from pcs_test.tools.assertions import AssertPcsMixin
-from pcs_test.tools.bin_mock import get_mock_settings
-from pcs_test.tools.pcs_runner import PcsRunner
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs import resource
 from pcs.cli.common.parse_args import InputModifiers
 from pcs.common import const
 from pcs.common.str_tools import format_list
 
+from pcs_test.tier1.cib_resource.common import ResourceTest
+from pcs_test.tools.assertions import AssertPcsMixin
+from pcs_test.tools.bin_mock import get_mock_settings
+from pcs_test.tools.pcs_runner import PcsRunner
+
 # pylint: disable=invalid-name
 # pylint: disable=no-self-use
 # pylint: disable=unused-argument
 # pylint: disable=too-many-lines
 # pylint: disable=too-many-public-methods
 
-ERRORS_HAVE_OCURRED = (
+ERRORS_HAVE_OCCURRED = (
     "Error: Errors have occurred, therefore pcs is unable to continue\n"
 )
 
@@ -426,7 +429,7 @@ class SuccessOperations(ResourceTest):
             </resources>""",
         )
 
-    def test_merging_default_ops_explictly_specified(self):
+    def test_merging_default_ops_explicitly_specified(self):
         self.assert_effect(
             "resource create R ocf:heartbeat:Dummy op start timeout=200".split(),
             """<resources>
@@ -935,7 +938,7 @@ class FailOrWarn(ResourceTest):
             "Error: Agent 'ocf:heartbeat:NoExisting' is not installed or "
             "does not provide valid metadata:( crm_resource:)? Metadata "
             "query for ocf:heartbeat:NoExisting failed:.+"
-            ", use --force to override\n$",
+            f", use --force to override\n{ERRORS_HAVE_OCCURRED}$",
             re.MULTILINE,
         )
         self.assert_pcs_fail(
@@ -975,14 +978,14 @@ class FailOrWarn(ResourceTest):
         self.assert_pcs_fail(
             "resource create R invalid_agent_name".split(),
             "Error: Unable to find agent 'invalid_agent_name', try specifying"
-            " its full name\n",
+            " its full name\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_on_invalid_resource_agent_name_even_if_forced(self):
         self.assert_pcs_fail(
             "resource create R invalid_agent_name --force".split(),
             "Error: Unable to find agent 'invalid_agent_name', try specifying"
-            " its full name\n",
+            " its full name\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_invalid_agent(self):
@@ -992,7 +995,7 @@ class FailOrWarn(ResourceTest):
             " standard:provider:type when standard is 'ocf' or"
             " standard:type otherwise. List of standards and providers can"
             " be obtained by using commands 'pcs resource standards' and"
-            " 'pcs resource providers'\n",
+            " 'pcs resource providers'.\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_vail_when_agent_class_is_not_allowed(self):
@@ -1002,7 +1005,7 @@ class FailOrWarn(ResourceTest):
             " standard:provider:type when standard is 'ocf' or"
             " standard:type otherwise. List of standards and providers can"
             " be obtained by using commands 'pcs resource standards' and"
-            " 'pcs resource providers'\n",
+            " 'pcs resource providers'.\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_missing_provider_with_ocf_resource_agent(self):
@@ -1012,7 +1015,7 @@ class FailOrWarn(ResourceTest):
             " standard:provider:type when standard is 'ocf' or"
             " standard:type otherwise. List of standards and providers can"
             " be obtained by using commands 'pcs resource standards' and"
-            " 'pcs resource providers'\n",
+            " 'pcs resource providers'.\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_provider_appear_with_non_ocf_resource_agent(self):
@@ -1022,7 +1025,7 @@ class FailOrWarn(ResourceTest):
             " standard:provider:type when standard is 'ocf' or"
             " standard:type otherwise. List of standards and providers can"
             " be obtained by using commands 'pcs resource standards' and"
-            " 'pcs resource providers'\n",
+            " 'pcs resource providers'.\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_print_info_about_agent_completion(self):
@@ -1035,7 +1038,8 @@ class FailOrWarn(ResourceTest):
         self.assert_pcs_fail(
             "resource create R Dummy".split(),
             "Error: Multiple agents match 'Dummy', please specify full name:"
-            " 'ocf:heartbeat:Dummy', 'ocf:pacemaker:Dummy'\n",
+            " 'ocf:heartbeat:Dummy' or 'ocf:pacemaker:Dummy'\n"
+            + ERRORS_HAVE_OCCURRED,
         )
 
     def test_for_options_not_matching_resource_agent(self):
@@ -1043,18 +1047,17 @@ class FailOrWarn(ResourceTest):
             "resource create R ocf:heartbeat:Dummy a=b c=d".split(),
             "Error: invalid resource options: 'a', 'c', allowed options are: "
             "'fake', 'state', 'trace_file', 'trace_ra', use --force to "
-            "override\n" + ERRORS_HAVE_OCURRED,
+            "override\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_for_missing_options_of_resource_agent(self):
         self.assert_pcs_fail(
             "resource create --no-default-ops R IPaddr2".split(),
             (
-                "Error: required resource option 'ip' is missing,"
-                " use --force to override\n"
-                + ERRORS_HAVE_OCURRED
-                + "Assumed agent name 'ocf:heartbeat:IPaddr2' (deduced from"
+                "Assumed agent name 'ocf:heartbeat:IPaddr2' (deduced from"
                 " 'IPaddr2')\n"
+                "Error: required resource option 'ip' is missing,"
+                " use --force to override\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1081,7 +1084,7 @@ class FailOrWarn(ResourceTest):
             (
                 "Error: invalid operation id '#O',"
                 " '#' is not a valid first character for a operation id\n"
-                + ERRORS_HAVE_OCURRED
+                + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1120,7 +1123,7 @@ class FailOrWarn(ResourceTest):
                 "Error: 'monitro' is not a valid operation name value, use"
                 " 'meta-data', 'migrate_from', 'migrate_to', 'monitor',"
                 " 'reload', 'start', 'stop', 'validate-all', use --force to"
-                " override\n" + ERRORS_HAVE_OCURRED
+                " override\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1145,7 +1148,7 @@ class FailOrWarn(ResourceTest):
                 "Error: Value '1' of option 'state' is not unique across "
                 "'ocf:pacemaker:Dummy' resources. Following resources are "
                 "configured with the same value of the instance attribute: "
-                "'R1', use --force to override\n" + ERRORS_HAVE_OCURRED
+                "'R1', use --force to override\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1174,7 +1177,7 @@ class FailOrWarn(ResourceTest):
                 "'ocf:pacemaker:Dummy' resources. Following resources are "
                 "configured with the same value of the instance attribute: "
                 "'R1', 'R2', 'R3', use --force to override\n"
-                + ERRORS_HAVE_OCURRED
+                + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1211,7 +1214,7 @@ class FailOrWarnOp(ResourceTest):
                 "Error: multiple specification of the same operation with the"
                 " same interval:\n"
                 "monitor with intervals 1h, 3600sec\n"
-                "monitor with intervals 1min, 60s\n" + ERRORS_HAVE_OCURRED
+                "monitor with intervals 1min, 60s\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1235,7 +1238,7 @@ class FailOrWarnOp(ResourceTest):
             " are: 'OCF_CHECK_LEVEL', 'description', 'enabled', 'id',"
             " 'interval', 'interval-origin', 'name', 'on-fail',"
             " 'record-pending', 'role', 'start-delay', 'timeout'\n"
-            + ERRORS_HAVE_OCURRED,
+            + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_on_invalid_role(self):
@@ -1248,7 +1251,7 @@ class FailOrWarnOp(ResourceTest):
                 "Error: 'abc' is not a valid role value, use {}\n".format(
                     format_list(const.PCMK_ROLES)
                 )
-                + ERRORS_HAVE_OCURRED
+                + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1262,7 +1265,7 @@ class FailOrWarnOp(ResourceTest):
                 "Error: 'abc' is not a valid role value, use {}\n".format(
                     format_list(const.PCMK_ROLES)
                 )
-                + ERRORS_HAVE_OCURRED
+                + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1275,7 +1278,7 @@ class FailOrWarnOp(ResourceTest):
             (
                 "Error: 'Abc' is not a valid on-fail value, use 'block', "
                 "'demote', 'fence', 'ignore', 'restart', 'restart-container', "
-                "'standby', 'stop'\n" + ERRORS_HAVE_OCURRED
+                "'standby', 'stop'\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1287,7 +1290,7 @@ class FailOrWarnOp(ResourceTest):
             ).split(),
             (
                 "Error: 'Abc' is not a valid record-pending value, use '0', "
-                "'1', 'false', 'true'\n" + ERRORS_HAVE_OCURRED
+                "'1', 'false', 'true'\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1299,7 +1302,7 @@ class FailOrWarnOp(ResourceTest):
             ).split(),
             (
                 "Error: 'Abc' is not a valid enabled value, use '0', '1', "
-                "'false', 'true'\n" + ERRORS_HAVE_OCURRED
+                "'false', 'true'\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1312,7 +1315,7 @@ class FailOrWarnOp(ResourceTest):
             (
                 "Error: Only one of resource operation options "
                 "'interval-origin' and 'start-delay' can be used\n"
-                + ERRORS_HAVE_OCURRED
+                + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1322,7 +1325,7 @@ class FailOrWarnGroup(ResourceTest):
         self.assert_pcs_fail(
             "resource create R ocf:heartbeat:Dummy --group 1".split(),
             "Error: invalid group name '1', '1' is not a valid first character"
-            " for a group name\n",
+            " for a group name\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_try_use_id_of_another_element(self):
@@ -1351,7 +1354,8 @@ class FailOrWarnGroup(ResourceTest):
                 "resource create R2 ocf:heartbeat:Dummy "
                 "--group R1-meta_attributes"
             ).split(),
-            "Error: 'R1-meta_attributes' is not a group\n",
+            "Error: 'R1-meta_attributes' is not a group\n"
+            + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_entered_both_after_and_before(self):
@@ -1388,13 +1392,13 @@ class FailOrWarnGroup(ResourceTest):
         )
         self.assert_pcs_fail(
             "resource create R2 ocf:heartbeat:Dummy --group G1 --before R1".split(),
-            "Error: there is no resource 'R1' in the group 'G1'\n",
+            "Error: 'R1' does not exist\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_use_before_with_new_group(self):
         self.assert_pcs_fail(
             "resource create R2 ocf:heartbeat:Dummy --group G1 --before R1".split(),
-            "Error: there is no resource 'R1' in the group 'G1'\n",
+            "Error: 'R1' does not exist\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_after_does_not_exist(self):
@@ -1403,13 +1407,13 @@ class FailOrWarnGroup(ResourceTest):
         )
         self.assert_pcs_fail(
             "resource create R2 ocf:heartbeat:Dummy --group G1 --after R1".split(),
-            "Error: there is no resource 'R1' in the group 'G1'\n",
+            "Error: 'R1' does not exist\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_use_after_with_new_group(self):
         self.assert_pcs_fail(
             "resource create R2 ocf:heartbeat:Dummy --group G1 --after R1".split(),
-            "Error: there is no resource 'R1' in the group 'G1'\n",
+            "Error: 'R1' does not exist\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def test_fail_when_on_pacemaker_remote_attempt(self):
@@ -1418,7 +1422,7 @@ class FailOrWarnGroup(ResourceTest):
             (
                 "Error: this command is not sufficient for creating a remote"
                 " connection, use 'pcs cluster node add-remote'"
-                ", use --force to override\n" + ERRORS_HAVE_OCURRED
+                ", use --force to override\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1439,10 +1443,9 @@ class FailOrWarnGroup(ResourceTest):
         self.assert_pcs_fail(
             "resource create R2 ocf:pacemaker:remote server=R --force".split(),
             (
-                "Error: 'R' already exists\n"
-                + ERRORS_HAVE_OCURRED
-                + "Warning: this command is not sufficient for creating a "
+                "Warning: this command is not sufficient for creating a "
                 "remote connection, use 'pcs cluster node add-remote'\n"
+                "Error: 'R' already exists\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1456,10 +1459,9 @@ class FailOrWarnGroup(ResourceTest):
         self.assert_pcs_fail(
             "resource create R2 ocf:pacemaker:remote --force".split(),
             (
-                "Error: 'R2' already exists\n"
-                + ERRORS_HAVE_OCURRED
-                + "Warning: this command is not sufficient for creating a "
+                "Warning: this command is not sufficient for creating a "
                 "remote connection, use 'pcs cluster node add-remote'\n"
+                "Error: 'R2' already exists\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1476,10 +1478,9 @@ class FailOrWarnGroup(ResourceTest):
                 "meta remote-node=R --force"
             ).split(),
             (
-                "Error: 'R' already exists\n"
-                + ERRORS_HAVE_OCURRED
-                + "Warning: this command is not sufficient for creating a "
+                "Warning: this command is not sufficient for creating a "
                 "guest node, use 'pcs cluster node add-guest'\n"
+                "Error: 'R' already exists\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1496,10 +1497,9 @@ class FailOrWarnGroup(ResourceTest):
                 "meta remote-node=HOST --force"
             ).split(),
             (
-                "Error: 'HOST' already exists\n"
-                + ERRORS_HAVE_OCURRED
-                + "Warning: this command is not sufficient for creating a "
+                "Warning: this command is not sufficient for creating a "
                 "guest node, use 'pcs cluster node add-guest'\n"
+                "Error: 'HOST' already exists\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1516,10 +1516,9 @@ class FailOrWarnGroup(ResourceTest):
                 "meta remote-node=A remote-addr=HOST --force"
             ).split(),
             (
-                "Error: 'HOST' already exists\n"
-                + ERRORS_HAVE_OCURRED
-                + "Warning: this command is not sufficient for creating a "
+                "Warning: this command is not sufficient for creating a "
                 "guest node, use 'pcs cluster node add-guest'\n"
+                "Error: 'HOST' already exists\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
@@ -1545,7 +1544,7 @@ class FailOrWarnGroup(ResourceTest):
             (
                 "Error: this command is not sufficient for creating a guest "
                 "node, use 'pcs cluster node add-guest', use --force to "
-                "override\n" + ERRORS_HAVE_OCURRED
+                "override\n" + ERRORS_HAVE_OCCURRED
             ),
         )
 
