@@ -2,19 +2,19 @@ from functools import partial
 from unittest import TestCase
 
 from pcs_test.tools.assertions import (
-    ac,
     AssertPcsMixin,
+    ac,
 )
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
-    get_test_resource as rc,
     get_tmp_dir,
     get_tmp_file,
     skip_unless_root,
     write_file_to_tmpfile,
 )
 from pcs_test.tools.pcs_runner import (
-    pcs,
     PcsRunner,
+    pcs,
 )
 
 
@@ -44,7 +44,7 @@ class UidGidTest(TestCase):
         o, r = _pcs("cluster uidgid rm".split())
         assert r == 1
         assert o.startswith(
-            "Hint: This command has been replaced with 'pcs cluster uidgid "
+            "Error: This command has been replaced with 'pcs cluster uidgid "
             "delete', 'pcs cluster uidgid remove'."
         )
 
@@ -80,11 +80,9 @@ class UidGidTest(TestCase):
 
         o, r = _pcs("cluster uidgid rm uid=testuid2 gid=testgid".split())
         assert r == 1
-        ac(
-            o,
-            "'pcs cluster uidgid rm' has been deprecated, use 'pcs cluster "
-            "uidgid delete' or 'pcs cluster uidgid remove' instead\n"
-            "Error: no uidgid files with uid=testuid2 and gid=testgid found\n",
+        assert o.startswith(
+            "Error: This command has been replaced with 'pcs cluster uidgid "
+            "delete', 'pcs cluster uidgid remove'."
         )
 
         o, r = _pcs("cluster uidgid".split())
@@ -115,12 +113,8 @@ class UidGidTest(TestCase):
         assert r == 0
         ac(o, "UID/GID: uid=testuid gid=testgid\n")
 
-        o, r = _pcs("cluster uidgid rm uid=testuid gid=testgid".split())
-        ac(
-            o,
-            "'pcs cluster uidgid rm' has been deprecated, use 'pcs cluster "
-            "uidgid delete' or 'pcs cluster uidgid remove' instead\n",
-        )
+        o, r = _pcs("cluster uidgid delete uid=testuid gid=testgid".split())
+        ac(o, "")
         assert r == 0
 
         o, r = _pcs("cluster uidgid".split())
