@@ -1,18 +1,17 @@
-from unittest import TestCase
 from textwrap import dedent
+from unittest import TestCase
 
 from lxml import etree
 
 from pcs_test.tools.cib import get_assert_pcs_effect_mixin
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
-    get_test_resource as rc,
     get_tmp_file,
     outdent,
     write_file_to_tmpfile,
 )
 from pcs_test.tools.pcs_runner import PcsRunner
 
-
 empty_cib = rc("cib-empty.xml")
 tags_cib = rc("cib-tags.xml")
 
@@ -56,6 +55,12 @@ class TestTagMixin(
                 <tag id="tag3">
                     <obj_ref id="y2-clone"/>
                 </tag>
+                <tag id="tag-mixed-stonith-devices-and-resources">
+                    <obj_ref id="fence-rh-2"/>
+                    <obj_ref id="y1"/>
+                    <obj_ref id="fence-rh-1"/>
+                    <obj_ref id="x3"/>
+                </tag>
                 {append}
             </tags>
         """
@@ -162,6 +167,7 @@ class TagCreate(TestTagMixin, TestCase):
 
 class TagConfigListBase(TestTagMixin):
     command = None
+    deprecation_msg = ""
 
     def test_config_empty(self):
         write_file_to_tmpfile(empty_cib, self.temp_cib)
@@ -173,14 +179,14 @@ class TagConfigListBase(TestTagMixin):
 
         self.assert_pcs_success(
             ["tag", self.command],
-            " No tags defined\n",
+            self.deprecation_msg + " No tags defined\n",
         )
 
     def test_config_tag_does_not_exist(self):
         self.assert_pcs_fail(
             ["tag", self.command, "notag2", "notag1"],
             (
-                "Error: tag 'notag2' does not exist\n"
+                self.deprecation_msg + "Error: tag 'notag2' does not exist\n"
                 "Error: tag 'notag1' does not exist\n"
                 "Error: Errors have occurred, therefore pcs is unable to "
                 "continue\n"
@@ -191,7 +197,8 @@ class TagConfigListBase(TestTagMixin):
     def test_config_tags_defined(self):
         self.assert_pcs_success(
             ["tag", self.command],
-            dedent(
+            self.deprecation_msg
+            + dedent(
                 """\
                 tag1
                   x1
@@ -202,6 +209,11 @@ class TagConfigListBase(TestTagMixin):
                   x2
                 tag3
                   y2-clone
+                tag-mixed-stonith-devices-and-resources
+                  fence-rh-2
+                  y1
+                  fence-rh-1
+                  x3
                 """
             ),
         )
@@ -209,7 +221,8 @@ class TagConfigListBase(TestTagMixin):
     def test_config_specified_tags(self):
         self.assert_pcs_success(
             ["tag", self.command, "tag2", "tag1"],
-            dedent(
+            self.deprecation_msg
+            + dedent(
                 """\
                 tag2
                   y1
@@ -235,6 +248,10 @@ class TagList(
     TestCase,
 ):
     command = "list"
+    deprecation_msg = (
+        "Deprecation Warning: This command is deprecated and will be removed. "
+        "Please use 'pcs tag config' instead.\n"
+    )
 
 
 class PcsConfigTagsTest(TestTagMixin, TestCase):
@@ -243,11 +260,9 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
         Cluster Name: test99
         Corosync Nodes:
          rh7-1 rh7-2
-        Pacemaker Nodes:
+        {pacemaker_nodes}
         {resources}
-        Stonith Devices:
-        Fencing Levels:
-        {constraints}
+        {stonith_devices}{fencing_levels}{constraints}
         Alerts:
          No alerts defined
 
@@ -262,7 +277,10 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
           Options:
         """
     )
+    empty_pacemaker_nodes = "Pacemaker Nodes:"
     empty_resources = "\nResources:\n"
+    empty_stonith_devices = "Stonith Devices:\n"
+    empty_fencing_levels = "Fencing Levels:\n"
     empty_constraints = outdent(
         """
         Location Constraints:
@@ -277,23 +295,77 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
          No tags defined
         """
     )
+    expected_pacemaker_nodes = outdent(
+        """\
+        Pacemaker Nodes:
+         rh-1 rh-2
+        """
+    )
     expected_resources = outdent(
         # pylint: disable=line-too-long
-        """
+        """\
         Resources:
-         Resource: not-in-tags (class=ocf provider=pacemaker type=Dummy)
-          Operations: monitor interval=10s timeout=20s (not-in-tags-monitor-interval-10s)
-         Resource: x1 (class=ocf provider=pacemaker type=Dummy)
-          Operations: monitor interval=10s timeout=20s (x1-monitor-interval-10s)
-         Resource: x2 (class=ocf provider=pacemaker type=Dummy)
-          Operations: monitor interval=10s timeout=20s (x2-monitor-interval-10s)
-         Resource: x3 (class=ocf provider=pacemaker type=Dummy)
-          Operations: monitor interval=10s timeout=20s (x3-monitor-interval-10s)
-         Resource: y1 (class=ocf provider=pacemaker type=Dummy)
-          Operations: monitor interval=10s timeout=20s (y1-monitor-interval-10s)
-         Clone: y2-clone
-          Resource: y2 (class=ocf provider=pacemaker type=Dummy)
-           Operations: monitor interval=10s timeout=20s (y2-monitor-interval-10s)
+          Resource: not-in-tags (class=ocf provider=pacemaker type=Dummy)
+            Operations:
+              monitor: not-in-tags-monitor-interval-10s
+                interval=10s
+                timeout=20s
+          Resource: x1 (class=ocf provider=pacemaker type=Dummy)
+            Operations:
+              monitor: x1-monitor-interval-10s
+                interval=10s
+                timeout=20s
+          Resource: x2 (class=ocf provider=pacemaker type=Dummy)
+            Operations:
+              monitor: x2-monitor-interval-10s
+                interval=10s
+                timeout=20s
+          Resource: x3 (class=ocf provider=pacemaker type=Dummy)
+            Operations:
+              monitor: x3-monitor-interval-10s
+                interval=10s
+                timeout=20s
+          Resource: y1 (class=ocf provider=pacemaker type=Dummy)
+            Operations:
+              monitor: y1-monitor-interval-10s
+                interval=10s
+                timeout=20s
+          Clone: y2-clone
+            Resource: y2 (class=ocf provider=pacemaker type=Dummy)
+              Operations:
+                monitor: y2-monitor-interval-10s
+                  interval=10s
+                  timeout=20s
+        """
+    )
+    expected_stonith_devices = outdent(
+        """\
+        Stonith Devices:
+          Resource: fence-rh-1 (class=stonith type=fence_xvm)
+            Operations:
+              monitor: fence-rh-1-monitor-interval-60s
+                interval=60s
+          Resource: fence-rh-2 (class=stonith type=fence_xvm)
+            Operations:
+              monitor: fence-rh-2-monitor-interval-60s
+                interval=60s
+          Resource: fence-kdump (class=stonith type=fence_kdump)
+            Attributes: fence-kdump-instance_attributes
+              pcmk_host_list="rh-1 rh-2"
+            Operations:
+              monitor: fence-kdump-monitor-interval-60s
+                interval=60s
+        """
+    )
+    expected_fencing_levels = outdent(
+        """\
+        Fencing Levels:
+          Target: rh-1
+            Level 1 - fence-kdump
+            Level 2 - fence-rh-1
+          Target: rh-2
+            Level 1 - fence-kdump
+            Level 2 - fence-rh-2
         """
     )
     expected_tags = outdent(
@@ -308,6 +380,11 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
            x2
          tag3
            y2-clone
+         tag-mixed-stonith-devices-and-resources
+           fence-rh-2
+           y1
+           fence-rh-1
+           x3
         """
     )
     expected_constraints = outdent(
@@ -334,12 +411,18 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
     def fixture_expected_config(
         self,
         constraints=empty_constraints,
+        pacemaker_nodes=empty_pacemaker_nodes,
         resources=empty_resources,
+        stonith_devices=empty_stonith_devices,
+        fencing_levels=empty_fencing_levels,
         tags=empty_tags,
     ):
         return self.config_template.format(
             constraints=constraints,
+            pacemaker_nodes=pacemaker_nodes,
             resources=resources,
+            stonith_devices=stonith_devices,
+            fencing_levels=fencing_levels,
             tags=tags,
         )
 
@@ -356,7 +439,10 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
             ["config"],
             self.fixture_expected_config(
                 constraints=self.expected_constraints,
+                pacemaker_nodes=self.expected_pacemaker_nodes,
                 resources=self.expected_resources,
+                stonith_devices=self.expected_stonith_devices,
+                fencing_levels=self.expected_fencing_levels,
                 tags=self.expected_tags,
             ),
         )
@@ -392,7 +478,14 @@ class TagRemoveDeleteBase(TestTagMixin):
 
     def test_remove_all_tags(self):
         self.assert_effect(
-            ["tag", self.command, "tag1", "tag2", "tag3"],
+            [
+                "tag",
+                self.command,
+                "tag1",
+                "tag2",
+                "tag3",
+                "tag-mixed-stonith-devices-and-resources",
+            ],
             """
             <tags/>
             """,
