@@ -1,18 +1,14 @@
 import os
 
-from lxml import etree
+from pcs import settings
 
-from pcs_test.tools.command_env.mock_runner import (
-    Call as RunnerCall,
-    CheckStdinEqualXml,
-)
-from pcs_test.tools.fixture import complete_state_resources
+from pcs_test.tools.command_env.mock_runner import Call as RunnerCall
+from pcs_test.tools.command_env.mock_runner import CheckStdinEqualXml
 from pcs_test.tools.fixture_cib import modify_cib
+from pcs_test.tools.fixture_crm_mon import complete_state
 from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.xml import etree_to_str
 
-from pcs import settings
-
 # pylint: disable=too-many-arguments
 
 DEFAULT_WAIT_TIMEOUT = 10
@@ -22,6 +18,8 @@ AGENT_FILENAME_MAP = {
     "ocf:pacemaker:remote": "resource_agent_ocf_pacemaker_remote.xml",
     "ocf:heartbeat:IPaddr2": "resource_agent_ocf_heartbeat_ipaddr2.xml",
     "ocf:pacemaker:booth-site": "resource_agent_ocf_pacemaker_booth-site.xml",
+    "ocf:pacemaker:Stateful": "resource_agent_ocf_pacemaker_stateful_ocf_1.1.xml",
+    "stonith:fence_unfencing": "stonith_agent_fence_unfencing.xml",
 }
 
 RULE_IN_EFFECT_RETURNCODE = 0
@@ -29,65 +27,6 @@ RULE_EXPIRED_RETURNCODE = 110
 RULE_NOT_YET_IN_EFFECT_RETURNCODE = 111
 
 
-def _fixture_state_resources_xml(
-    resource_id="A",
-    resource_agent="ocf::heartbeat:Dummy",
-    role="Started",
-    failed="false",
-    node_name="node1",
-):
-    return """
-        <resources>
-            <resource
-                id="{resource_id}"
-                resource_agent="{resource_agent}"
-                role="{role}"
-                failed="{failed}"
-            >
-                <node name="{node_name}" id="1" cached="false"/>
-            </resource>
-        </resources>
-        """.format(
-        resource_id=resource_id,
-        resource_agent=resource_agent,
-        role=role,
-        failed=failed,
-        node_name=node_name,
-    )
-
-
-def _fixture_state_node_xml(
-    id,
-    name,
-    type="member",
-    online=True,
-    standby=False,
-    standby_onfail=False,
-    maintenance=False,
-    pending=False,
-    unclean=False,
-    shutdown=False,
-    expected_up=True,
-    is_dc=False,
-    resources_running=0,
-):
-    # This function uses a "clever" way of defaulting an input **dict containing
-    # attributes of an xml element.
-    # pylint: disable=unused-argument
-    # pylint: disable=invalid-name
-    # pylint: disable=redefined-builtin
-    # pylint: disable=too-many-locals
-    attrs = locals()
-    xml_attrs = []
-    for attr_name, attr_value in attrs.items():
-        if attr_value is True:
-            attr_value = "true"
-        elif attr_value is False:
-            attr_value = "false"
-        xml_attrs.append('{0}="{1}"'.format(attr_name, attr_value))
-    return "<node {0}/>".format(" ".join(xml_attrs))
-
-
 class PcmkShortcuts:
     # pylint: disable=too-many-public-methods
     def __init__(self, calls):
@@ -120,6 +59,7 @@ class PcmkShortcuts:
         name="runner.pcmk.can_fence_history_status",
         stderr="--fence-history",
         instead=None,
+        env=None,
     ):
         """
         Create a call to check if fence_history is supported by crm_mon
@@ -128,10 +68,11 @@ class PcmkShortcuts:
         string stderr -- crm_mon help text
         string instead -- key of call instead of which this new call is to be
             placed
+        dict env -- CommandRunner environment variables
         """
         self.__calls.place(
             name,
-            RunnerCall(["crm_mon", "--help-all"], stderr=stderr),
+            RunnerCall(["crm_mon", "--help-all"], stderr=stderr, env=env),
             instead=instead,
         )
 
@@ -219,11 +160,11 @@ class PcmkShortcuts:
         name="runner.pcmk.load_state",
         filename="crm_mon.minimal.xml",
         resources=None,
-        raw_resources=None,
         nodes=None,
         stdout="",
         stderr="",
         returncode=0,
+        env=None,
     ):
         """
         Create call for loading pacemaker state.
@@ -231,75 +172,44 @@ class PcmkShortcuts:
         string name -- key of the call
         string filename -- points to file with the status in the content
         string resources -- xml - resources section, will be put to state
-        string nodes -- iterable of node dicts
+        string nodes -- xml - nodes section, will be put to state
         string stdout -- crm_mon's stdout
         string stderr -- crm_mon's stderr
         int returncode -- crm_mon's returncode
+        dict env -- CommandRunner environment variables
         """
-        # pylint: disable=too-many-boolean-expressions
-        if (resources or raw_resources is not None or nodes) and (
-            stdout or stderr or returncode
-        ):
+        if (resources or nodes) and (stdout or stderr or returncode):
             raise AssertionError(
                 "Cannot specify resources or nodes when stdout, stderr or "
                 "returncode is specified"
             )
-        if resources and raw_resources is not None:
-            raise AssertionError(
-                "Cannot use 'resources' and 'raw_resources' together"
-            )
+
+        command = ["crm_mon", "--one-shot", "--inactive", "--output-as", "xml"]
 
         if stdout or stderr or returncode:
             self.__calls.place(
                 name,
                 RunnerCall(
-                    ["crm_mon", "--one-shot", "--as-xml", "--inactive"],
+                    command,
                     stdout=stdout,
                     stderr=stderr,
                     returncode=returncode,
+                    env=env,
                 ),
             )
             return
 
         with open(rc(filename)) as a_file:
-            state = etree.fromstring(a_file.read())
-
-        if raw_resources is not None:
-            resources = _fixture_state_resources_xml(**raw_resources)
-        if resources:
-            state.append(complete_state_resources(etree.fromstring(resources)))
-
-        if nodes:
-            nodes_element = state.find("./nodes")
-            for node in nodes:
-                nodes_element.append(
-                    etree.fromstring(_fixture_state_node_xml(**node))
-                )
-
-        # set correct number of nodes and resources into the status
-        resources_count = len(
-            state.xpath(
-                " | ".join(
-                    [
-                        "./resources/bundle",
-                        "./resources/clone",
-                        "./resources/group",
-                        "./resources/resource",
-                    ]
-                )
-            )
-        )
-        nodes_count = len(state.findall("./nodes/node"))
-        state.find("./summary/nodes_configured").set("number", str(nodes_count))
-        state.find("./summary/resources_configured").set(
-            "number", str(resources_count)
-        )
+            state_xml = a_file.read()
 
         self.__calls.place(
             name,
             RunnerCall(
-                ["crm_mon", "--one-shot", "--as-xml", "--inactive"],
-                stdout=etree_to_str(state),
+                command,
+                stdout=etree_to_str(
+                    complete_state(state_xml, resources, nodes)
+                ),
+                env=env,
             ),
         )
 
@@ -312,17 +222,19 @@ class PcmkShortcuts:
         stdout="",
         stderr="",
         returncode=0,
+        env=None,
     ):
         """
         Create a call for loading plaintext pacemaker status
 
         str name -- key of the call
-        bool incative -- pass --inactive flag to crm_mon
+        bool inactive -- pass --inactive flag to crm_mon
         bool verbose -- pass flags for increased verbosity to crm_mon
         bool fence_history -- pass the flag for getting fence history to crm_mon
         str stdout -- crm_mon's stdout
         str stderr -- crm_mon's stderr
         int returncode -- crm_mon's returncode
+        dict env -- CommandRunner environment variables
         """
         flags = ["--one-shot"]
         if inactive:
@@ -340,6 +252,7 @@ class PcmkShortcuts:
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
+                env=env,
             ),
         )
 
@@ -349,6 +262,7 @@ class PcmkShortcuts:
         stdout="",
         stderr="",
         returncode=0,
+        env=None,
     ):
         """
         Create a call for loading plaintext tickets status
@@ -357,6 +271,7 @@ class PcmkShortcuts:
         str stdout -- crm_ticket's stdout
         str stderr -- crm_ticket's stderr
         int returncode -- crm_ticket's returncode
+        dict env -- CommandRunner environment variables
         """
         self.__calls.place(
             name,
@@ -365,6 +280,74 @@ class PcmkShortcuts:
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
+                env=env,
+            ),
+        )
+
+    def list_agents_standards(
+        self,
+        stdout="",
+        stderr="",
+        returncode=0,
+        env=None,
+        name="runner.pcmk.list_agents_standards",
+    ):
+        """
+        Create a call for listing agents standards
+        """
+        self.__calls.place(
+            name,
+            RunnerCall(
+                ["crm_resource", "--list-standards"],
+                stdout=stdout,
+                stderr=stderr,
+                returncode=returncode,
+                env=env,
+            ),
+        )
+
+    def list_agents_ocf_providers(
+        self,
+        stdout="",
+        stderr="",
+        returncode=0,
+        env=None,
+        name="runner.pcmk.list_agents_ocf_providers",
+    ):
+        """
+        Create a call for listing agents ocf providers
+        """
+        self.__calls.place(
+            name,
+            RunnerCall(
+                ["crm_resource", "--list-ocf-providers"],
+                stdout=stdout,
+                stderr=stderr,
+                returncode=returncode,
+                env=env,
+            ),
+        )
+
+    def list_agents_for_standard_and_provider(
+        self,
+        standard_provider,
+        stdout="",
+        stderr="",
+        returncode=0,
+        env=None,
+        name="runner.pcmk.list_agents_for_standard_and_provider",
+    ):
+        """
+        Create a call for listing agents of given standard and provider
+        """
+        self.__calls.place(
+            name,
+            RunnerCall(
+                ["crm_resource", "--list-agents", standard_provider],
+                stdout=stdout,
+                stderr=stderr,
+                returncode=returncode,
+                env=env,
             ),
         )
 
@@ -374,8 +357,10 @@ class PcmkShortcuts:
         agent_name="ocf:heartbeat:Dummy",
         agent_filename=None,
         agent_is_missing=False,
+        stdout=None,
         stderr=None,
         instead=None,
+        env=None,
     ):
         """
         Create call for loading resource agent metadata.
@@ -384,15 +369,28 @@ class PcmkShortcuts:
         string agent_name
         string agent_filename -- points to file with the agent metadata in the
             content
+        bool agent_is_missing -- create a response as if the agent was missing
         string instead -- key of call instead of which this new call is to be
             placed
+        dict env -- CommandRunner environment variables
         """
+        if env:
+            env = dict(env)
+        else:
+            env = {}
+        env["PATH"] = ":".join(
+            [
+                settings.fence_agent_binaries,
+                "/bin",
+                "/usr/bin",
+            ]
+        )
 
         if agent_filename:
             agent_metadata_filename = agent_filename
         elif agent_name in AGENT_FILENAME_MAP:
             agent_metadata_filename = AGENT_FILENAME_MAP[agent_name]
-        elif not agent_is_missing:
+        elif not stdout and not agent_is_missing:
             raise AssertionError(
                 (
                     "Filename with metadata of agent '{0}' not specified.\n"
@@ -402,7 +400,8 @@ class PcmkShortcuts:
                     " filename='FILENAME_HERE.xml')\n"
                     "  b) implicitly for agent '{0}' in 'AGENT_FILENAME_MAP' in"
                     " '{1}'\n"
-                    "Place agent metadata into '{2}FILENAME_HERE.xml'"
+                    "Place agent metadata into '{2}FILENAME_HERE.xml'\n"
+                    "Or define metadata directly in 'stdout' argument."
                 ).format(agent_name, os.path.realpath(__file__), rc(""))
             )
 
@@ -421,21 +420,25 @@ class PcmkShortcuts:
                     stdout="",
                     stderr=stderr,
                     returncode=74,
+                    env=env,
                 ),
                 instead=instead,
             )
             return
 
-        with open(rc(agent_metadata_filename)) as a_file:
-            self.__calls.place(
-                name,
-                RunnerCall(
-                    ["crm_resource", "--show-metadata", agent_name],
-                    stdout=a_file.read(),
-                    stderr=stderr,
-                ),
-                instead=instead,
-            )
+        if not stdout:
+            with open(rc(agent_metadata_filename)) as a_file:
+                stdout = a_file.read()
+        self.__calls.place(
+            name,
+            RunnerCall(
+                ["crm_resource", "--show-metadata", agent_name],
+                stdout=stdout,
+                stderr=stderr,
+                env=env,
+            ),
+            instead=instead,
+        )
 
     def load_fenced_metadata(
         self,
@@ -559,6 +562,52 @@ class PcmkShortcuts:
             instead=instead,
         )
 
+    def resource_refresh(
+        self,
+        name="runner.pcmk.refresh",
+        instead=None,
+        before=None,
+        resource=None,
+        node=None,
+        strict=False,
+        stdout="",
+        stderr="",
+        returncode=0,
+    ):
+        """
+        Create a call for crm_resource --refresh
+
+        string name -- the key of this call
+        string instead -- the key of a call instead of which this new call is to
+            be placed
+        string before -- the key of a call before which this new call is to be
+            placed
+        string resource -- the id of a resource to be cleaned
+        string node -- the name of the node where resources should be cleaned
+        bool strict -- strict mode of 'crm_resource refresh' enabled?
+        string stdout -- crm_resource's stdout
+        string stderr -- crm_resource's stderr
+        int returncode -- crm_resource's returncode
+        """
+        cmd = ["crm_resource", "--refresh"]
+        if resource:
+            cmd.extend(["--resource", resource])
+        if node:
+            cmd.extend(["--node", node])
+        if strict:
+            cmd.extend(["--force"])
+        self.__calls.place(
+            name,
+            RunnerCall(
+                cmd,
+                stdout=stdout,
+                stderr=stderr,
+                returncode=returncode,
+            ),
+            before=before,
+            instead=instead,
+        )
+
     def resource_move(
         self,
         name="runner.pcmk.resource_move",
@@ -571,6 +620,7 @@ class PcmkShortcuts:
         stdout="",
         stderr="",
         returncode=0,
+        env=None,
     ):
         """
         Create a call for crm_resource --move
@@ -587,6 +637,7 @@ class PcmkShortcuts:
         string stdout -- crm_resource's stdout
         string stderr -- crm_resource's stderr
         int returncode -- crm_resource's returncode
+        dict env -- CommandRunner environment variables
         """
         # arguments are used via locals()
         # pylint: disable=unused-argument
@@ -643,6 +694,7 @@ class PcmkShortcuts:
         stdout="",
         stderr="",
         returncode=0,
+        env=None,
     ):
         """
         Create a call for crm_resource --clear
@@ -659,6 +711,7 @@ class PcmkShortcuts:
         string stdout -- crm_resource's stdout
         string stderr -- crm_resource's stderr
         int returncode -- crm_resource's returncode
+        dict env -- CommandRunner environment variables
         """
         # arguments are used via locals()
         # pylint: disable=unused-argument
@@ -681,6 +734,7 @@ class PcmkShortcuts:
         stdout="",
         stderr="",
         returncode=0,
+        env=None,
     ):
         cmd = ["crm_resource", action]
         if resource:
@@ -700,6 +754,7 @@ class PcmkShortcuts:
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
+                env=env,
             ),
             before=before,
             instead=instead,
@@ -733,18 +788,81 @@ class PcmkShortcuts:
         if returncode is None:
             returncode = self.default_wait_error_returncode if stderr else 0
 
+        cmd = ["crm_resource", "--wait"]
+        if timeout != 0:
+            cmd.append(
+                "--timeout={0}".format(
+                    timeout
+                    if timeout is not None
+                    else self.default_wait_timeout
+                )
+            )
+        self.__calls.place(
+            name,
+            RunnerCall(cmd, stderr=stderr, returncode=returncode),
+        )
+
+    def is_resource_digests_supported(
+        self,
+        name="runner.pcmk.is_resource_digests_supported",
+        is_supported=True,
+    ):
+        """
+        Create call for `crm_resource --help-all`. If support_digest is True, option
+        --digest is included in command output.
+
+        name -- key of the call
+        is_supported -- flags which decides if digests are supported
+        """
+        self.__calls.place(
+            name,
+            RunnerCall(
+                ["crm_resource", "--help-all"],
+                stdout="--digests" if is_supported else "",
+                stderr="",
+                returncode=0,
+            ),
+        )
+
+    def resource_digests(
+        self,
+        resource_id,
+        node_name,
+        name="runner.pcmk.resource_digests",
+        args=None,
+        stdout="",
+        stderr="",
+        returncode=0,
+    ):
+        """
+        Create call for crm_resource digests
+
+        resource_id -- id of a resource
+        node_name -- name of the node where the resource is running
+        name -- key of the call
+        args -- additional arguments for crm_resource
+        stdout -- crm_resource's stdout
+        stderr -- crm_resource's stderr
+        returncode -- crm_resource's returncode
+        """
+        if args is None:
+            args = []
+
         self.__calls.place(
             name,
             RunnerCall(
                 [
                     "crm_resource",
-                    "--wait",
-                    "--timeout={0}".format(
-                        timeout
-                        if timeout is not None
-                        else self.default_wait_timeout
-                    ),
+                    "--digests",
+                    "--resource",
+                    resource_id,
+                    "--node",
+                    node_name,
+                    "--output-as",
+                    "xml",
+                    *args,
                 ],
+                stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
             ),
@@ -756,12 +874,14 @@ class PcmkShortcuts:
         cib_tempfile=None,
         stderr=None,
         verbose=False,
+        env=None,
     ):
         """
         Create call that checks that wait for idle is supported
 
         string name -- key of the call
         string before -- key of call before which this new call is to be placed
+        dict env -- CommandRunner environment variables
         """
         cmd = ["crm_verify"]
         if verbose:
@@ -776,6 +896,7 @@ class PcmkShortcuts:
                 cmd,
                 stderr=("" if stderr is None else stderr),
                 returncode=(0 if stderr is None else 55),
+                env=env,
             ),
         )
 
@@ -785,6 +906,7 @@ class PcmkShortcuts:
         stderr="",
         returncode=0,
         name="runner.pcmk.remove_node",
+        env=None,
     ):
         self.__calls.place(
             name,
@@ -792,6 +914,7 @@ class PcmkShortcuts:
                 ["crm_node", "--force", "--remove", node_name],
                 stderr=stderr,
                 returncode=returncode,
+                env=env,
             ),
         )
 
@@ -799,12 +922,14 @@ class PcmkShortcuts:
         self,
         new_cib_filepath,
         transitions_filepath,
+        cib_xml=None,
         cib_modifiers=None,
         cib_load_name="runner.cib.load",
         stdout="",
         stderr="",
         returncode=0,
         name="runner.pcmk.simulate_cib",
+        env=None,
         **modifier_shortcuts,
     ):
         """
@@ -812,6 +937,7 @@ class PcmkShortcuts:
 
         string new_cib_filepath -- a temp file for storing a new cib
         string transitions_filepath -- a temp file for storing transitions
+        string cib_xml -- cib which will be used for a simulation
         list of callable modifiers -- every callable takes etree.Element and
             returns new etree.Element with desired modification
         string cib_load_name -- key of a call from whose stdout the cib is taken
@@ -819,6 +945,7 @@ class PcmkShortcuts:
         string stderr -- pacemaker's stderr
         int returncode -- pacemaker's returncode
         string name -- key of the call
+        dict env -- runner environment variables
         dict modifier_shortcuts -- a new modifier is generated from each
             modifier shortcut.
             As key there can be keys of MODIFIER_GENERATORS.
@@ -827,11 +954,12 @@ class PcmkShortcuts:
             MODIFIER_GENERATORS - please refer it when you are adding params
             here)
         """
-        cib_xml = modify_cib(
-            self.__calls.get(cib_load_name).stdout,
-            cib_modifiers,
-            **modifier_shortcuts,
-        )
+        if cib_xml is None:
+            cib_xml = modify_cib(
+                self.__calls.get(cib_load_name).stdout,
+                cib_modifiers,
+                **modifier_shortcuts,
+            )
         cmd = [
             "crm_simulate",
             "--simulate",
@@ -849,6 +977,7 @@ class PcmkShortcuts:
                 stderr=stderr,
                 returncode=returncode,
                 check_stdin=CheckStdinEqualXml(cib_xml),
+                env=env,
             ),
         )
 
