@@ -1,14 +1,21 @@
 import io
 import socket
+from dataclasses import dataclass
+from typing import (
+    Callable,
+    Iterable,
+    Optional,
+    Union,
+)
 from unittest import mock
 
-from pcs_test.tools.assertions import assert_report_item_list_equal
-
+import pcs.common.pcs_pycurl as pycurl
 from pcs.common.reports import (
     ReportItemSeverity,
     ReportProcessor,
 )
-import pcs.common.pcs_pycurl as pycurl
+
+from pcs_test.tools.assertions import assert_report_item_list_equal
 
 
 def get_getaddrinfo_mock(resolvable_addr_list):
@@ -34,6 +41,112 @@ def patch_getaddrinfo(test_case, addr_list):
     return addr_list
 
 
+FileContentType = Union[str, bytes, None, Exception]
+
+
+@dataclass(frozen=True)
+class TmpFileCall:
+    name: str
+    is_binary: bool = False
+    orig_content: FileContentType = None
+    new_content: FileContentType = None
+
+
+class TmpFileMock:
+    def __init__(
+        self,
+        calls: Iterable[TmpFileCall] = (),
+        file_content_checker: Optional[
+            Callable[[FileContentType, FileContentType], bool]
+        ] = None,
+    ):
+        self.set_calls(calls)
+        self._file_content_checker = file_content_checker
+
+    def _assert_file_content_equal(self, name, expected, real):
+        if expected is None and real is None:
+            return
+        eq_callback = lambda file1, file2: file1 != file2
+        if self._file_content_checker is not None:
+            eq_callback = self._file_content_checker
+        try:
+            is_not_equal = eq_callback(expected, real)
+        except AssertionError as e:
+            raise AssertionError(
+                f"Temporary file '{name}' content mismatch."
+            ) from e
+        if is_not_equal:
+            raise AssertionError(
+                f"Temporary file '{name}' content mismatch.\nExpected:\n"
+                f"{expected}\n\nReal:\n{real}"
+            )
+
+    def set_calls(self, calls):
+        self._calls = calls
+        self._calls_iter = iter(self._calls)
+
+    def get_mock_side_effect(self):
+        return self._mock_side_effect
+
+    def assert_all_done(self):
+        try:
+            next_unused = next(self._calls_iter)
+            raise AssertionError(
+                f"Not all temporary files were used; Next unused: {next_unused}"
+            )
+        except StopIteration:
+            pass
+
+    def _mock_side_effect(self, data=None, binary=False):
+        def _seek_callback(offset):
+            if offset != 0:
+                raise AssertionError(
+                    "Calling seek on a temporary file in tests with a parameter "
+                    "other than 0 is not supported"
+                )
+
+        try:
+            call = next(self._calls_iter)
+            if isinstance(call.orig_content, Exception):
+                raise call.orig_content
+            if binary != call.is_binary:
+                raise AssertionError(
+                    (
+                        "File mode mismatch; Expected: binary={expected}; "
+                        "Real: binary={real}"
+                    ).format(
+                        expected=call.is_binary,
+                        real=binary,
+                    )
+                )
+            self._assert_file_content_equal(call.name, call.orig_content, data)
+            tmp_file_mock = mock.NonCallableMock(
+                spec_set=["read", "seek", "name"]
+            )
+            tmp_file_mock.name = call.name
+            tmp_file_mock.seek.side_effect = _seek_callback
+            if call.new_content is None:
+                tmp_file_mock.seek.side_effect = AssertionError(
+                    "Seek call not expected"
+                )
+                tmp_file_mock.read.side_effect = AssertionError(
+                    "Read call not expected"
+                )
+            elif isinstance(call.new_content, Exception):
+                tmp_file_mock.read.side_effect = call.new_content
+            else:
+                tmp_file_mock.read.return_value = call.new_content
+            tmp_file_context_manager_mock = mock.NonCallableMagicMock(
+                spec_set=["__enter__", "__exit__"]
+            )
+            tmp_file_context_manager_mock.__enter__.return_value = tmp_file_mock
+            return tmp_file_context_manager_mock
+        except StopIteration:
+            raise AssertionError(
+                f"No more temporary files expected but got:\n{data}"
+            ) from None
+
+
 class MockLibraryReportProcessor(ReportProcessor):
     def __init__(self, debug=True):
         super().__init__()
@@ -106,8 +219,8 @@ class MockCurl:
     def getinfo(self, opt):
         try:
             return self._info[opt]
-        except KeyError:
-            AssertionError("info '#{0}' not defined".format(opt))
+        except KeyError as e:
+            raise AssertionError("info '#{0}' not defined".format(opt)) from e
 
     def perform(self):
         if self._error:
@@ -140,8 +253,8 @@ class MockCurlSimple:
     def getinfo(self, opt):
         try:
             return self._info[opt]
-        except KeyError:
-            AssertionError("info '#{0}' not defined".format(opt))
+        except KeyError as e:
+            raise AssertionError("info '#{0}' not defined".format(opt)) from e
 
 
 class MockCurlMulti:
@@ -149,7 +262,7 @@ class MockCurlMulti:
         self._number_of_performed_list = number_of_performed_list
         self._opts = {}
         self._handle_list = []
-        self._proccessed_list = []
+        self._processed_list = []
 
     @property
     def opts(self):
@@ -209,5 +322,5 @@ class MockCurlMulti:
                 # pylint: disable=unbalanced-tuple-unpacking
                 errno, msg = e.args
                 err_list.append((handle, errno, msg))
-            self._proccessed_list.append(handle)
+            self._processed_list.append(handle)
         return (0, ok_list, err_list)
