@@ -3,6 +3,8 @@ require 'json'
 require 'pcs.rb'
 require 'permissions.rb'
 
+# request: request.body contains json which represents parameters of pcs library
+#   command
 def route_api_v1(auth_user, params, request)
   req_map = {
     'acl-create-role/v1' => {
@@ -116,6 +118,11 @@ def route_api_v1(auth_user, params, request)
       :only_superuser => true,
       :permissions => nil,
     },
+    'cluster-generate-cluster-uuid/v1' => {
+      :cmd => 'cluster.generate_cluster_uuid',
+      :only_superuser => true,
+      :permission => nil,
+    },
     'constraint-colocation-create-with-set/v1' => {
       :cmd => 'constraint_colocation.create_with_set',
       :only_superuser => false,
@@ -191,11 +198,23 @@ def route_api_v1(auth_user, params, request)
       :only_superuser => false,
       :permissions => Permissions::READ,
     },
+    # deprecated, use resource-agent-get-agent-metadata/v1 instead
     'resource-agent-describe-agent/v1' => {
       :cmd => 'resource_agent.describe_agent',
       :only_superuser => false,
       :permissions => Permissions::READ,
     },
+    'resource-agent-get-agents-list/v1' => {
+      :cmd => 'resource_agent.get_agents_list',
+      :only_superuser => false,
+      :permissions => Permissions::READ,
+    },
+    'resource-agent-get-agent-metadata/v1' => {
+      :cmd => 'resource_agent.get_agent_metadata',
+      :only_superuser => false,
+      :permissions => Permissions::READ,
+    },
+    # deprecated, use resource-agent-get-agents-list/v1 instead
     'resource-agent-list-agents/v1' => {
       :cmd => 'resource_agent.list_agents',
       :only_superuser => false,
@@ -271,6 +290,11 @@ def route_api_v1(auth_user, params, request)
       :only_superuser => false,
       :permissions => Permissions::WRITE,
     },
+    'resource-move-autoclean/v1' => {
+      :cmd => 'resource.move_autoclean',
+      :only_superuser => false,
+      :permissions => Permissions::WRITE,
+    },
     'resource-unmanage/v1' => {
       :cmd => 'resource.unmanage',
       :only_superuser => false,
@@ -296,11 +320,18 @@ def route_api_v1(auth_user, params, request)
       :only_superuser => false,
       :permissions => Permissions::WRITE,
     },
+    'scsi-unfence-node-mpath/v1' => {
+      :cmd => 'scsi.unfence_node_mpath',
+      :only_superuser => false,
+      :permissions => Permissions::WRITE,
+    },
+    # deprecated, use resource-agent-get-agent-metadata/v1 instead
     'stonith-agent-describe-agent/v1' => {
       :cmd => 'stonith_agent.describe_agent',
       :only_superuser => false,
       :permissions => Permissions::READ,
     },
+    # deprecated, use resource-agent-get-agents-list/v1 instead
     'stonith-agent-list-agents/v1' => {
       :cmd => 'stonith_agent.list_agents',
       :only_superuser => false,
